# This file was automatically generated by SWIG (http://www.swig.org).
# Version 1.3.40
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.
# This file is compatible with both classic and new-style classes.

"""
CALCIUM python wrapping : Superv_Component class

"""

from sys import version_info
if version_info >= (2,6,0):
    def swig_import_helper():
        from os.path import dirname
        import imp
        fp = None
        try:
            fp, pathname, description = imp.find_module('_calcium', [dirname(__file__)])
        except ImportError:
            import _calcium
            return _calcium
        if fp is not None:
            try:
                _mod = imp.load_module('_calcium', fp, pathname, description)
            finally:
                fp.close()
            return _mod
    _calcium = swig_import_helper()
    del swig_import_helper
else:
    import _calcium
del version_info
try:
    _swig_property = property
except NameError:
    pass # Python < 2.2 doesn't have 'property'.
def _swig_setattr_nondynamic(self,class_type,name,value,static=1):
    if (name == "thisown"): return self.this.own(value)
    if (name == "this"):
        if type(value).__name__ == 'SwigPyObject':
            self.__dict__[name] = value
            return
    method = class_type.__swig_setmethods__.get(name,None)
    if method: return method(self,value)
    if (not static) or hasattr(self,name):
        self.__dict__[name] = value
    else:
        raise AttributeError("You cannot add attributes to %s" % self)

def _swig_setattr(self,class_type,name,value):
    return _swig_setattr_nondynamic(self,class_type,name,value,0)

def _swig_getattr(self,class_type,name):
    if (name == "thisown"): return self.this.own()
    method = class_type.__swig_getmethods__.get(name,None)
    if method: return method(self)
    raise AttributeError(name)

def _swig_repr(self):
    try: strthis = "proxy of " + self.this.__repr__()
    except: strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)

try:
    _object = object
    _newclass = 1
except AttributeError:
    class _object : pass
    _newclass = 0


class intArray(_object):
    """Proxy of C++ intArray class"""
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, intArray, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, intArray, name)
    __repr__ = _swig_repr
    def __init__(self, *args): 
        """__init__(self, size_t nelements) -> intArray"""
        this = _calcium.new_intArray(*args)
        try: self.this.append(this)
        except: self.this = this
    __swig_destroy__ = _calcium.delete_intArray
    __del__ = lambda self : None;
    def __getitem__(self, *args):
        """__getitem__(self, size_t index) -> int"""
        return _calcium.intArray___getitem__(self, *args)

    def __setitem__(self, *args):
        """__setitem__(self, size_t index, int value)"""
        return _calcium.intArray___setitem__(self, *args)

    def cast(self):
        """cast(self) -> int"""
        return _calcium.intArray_cast(self)

    def frompointer(*args):
        """frompointer(int t) -> intArray"""
        return _calcium.intArray_frompointer(*args)

    if _newclass:frompointer = staticmethod(frompointer)
    __swig_getmethods__["frompointer"] = lambda x: frompointer
intArray_swigregister = _calcium.intArray_swigregister
intArray_swigregister(intArray)

def intArray_frompointer(*args):
  """intArray_frompointer(int t) -> intArray"""
  return _calcium.intArray_frompointer(*args)

class longArray(_object):
    """Proxy of C++ longArray class"""
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, longArray, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, longArray, name)
    __repr__ = _swig_repr
    def __init__(self, *args): 
        """__init__(self, size_t nelements) -> longArray"""
        this = _calcium.new_longArray(*args)
        try: self.this.append(this)
        except: self.this = this
    __swig_destroy__ = _calcium.delete_longArray
    __del__ = lambda self : None;
    def __getitem__(self, *args):
        """__getitem__(self, size_t index) -> long"""
        return _calcium.longArray___getitem__(self, *args)

    def __setitem__(self, *args):
        """__setitem__(self, size_t index, long value)"""
        return _calcium.longArray___setitem__(self, *args)

    def cast(self):
        """cast(self) -> long"""
        return _calcium.longArray_cast(self)

    def frompointer(*args):
        """frompointer(long t) -> longArray"""
        return _calcium.longArray_frompointer(*args)

    if _newclass:frompointer = staticmethod(frompointer)
    __swig_getmethods__["frompointer"] = lambda x: frompointer
longArray_swigregister = _calcium.longArray_swigregister
longArray_swigregister(longArray)

def longArray_frompointer(*args):
  """longArray_frompointer(long t) -> longArray"""
  return _calcium.longArray_frompointer(*args)

class floatArray(_object):
    """Proxy of C++ floatArray class"""
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, floatArray, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, floatArray, name)
    __repr__ = _swig_repr
    def __init__(self, *args): 
        """__init__(self, size_t nelements) -> floatArray"""
        this = _calcium.new_floatArray(*args)
        try: self.this.append(this)
        except: self.this = this
    __swig_destroy__ = _calcium.delete_floatArray
    __del__ = lambda self : None;
    def __getitem__(self, *args):
        """__getitem__(self, size_t index) -> float"""
        return _calcium.floatArray___getitem__(self, *args)

    def __setitem__(self, *args):
        """__setitem__(self, size_t index, float value)"""
        return _calcium.floatArray___setitem__(self, *args)

    def cast(self):
        """cast(self) -> float"""
        return _calcium.floatArray_cast(self)

    def frompointer(*args):
        """frompointer(float t) -> floatArray"""
        return _calcium.floatArray_frompointer(*args)

    if _newclass:frompointer = staticmethod(frompointer)
    __swig_getmethods__["frompointer"] = lambda x: frompointer
floatArray_swigregister = _calcium.floatArray_swigregister
floatArray_swigregister(floatArray)

def floatArray_frompointer(*args):
  """floatArray_frompointer(float t) -> floatArray"""
  return _calcium.floatArray_frompointer(*args)

class doubleArray(_object):
    """Proxy of C++ doubleArray class"""
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, doubleArray, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, doubleArray, name)
    __repr__ = _swig_repr
    def __init__(self, *args): 
        """__init__(self, size_t nelements) -> doubleArray"""
        this = _calcium.new_doubleArray(*args)
        try: self.this.append(this)
        except: self.this = this
    __swig_destroy__ = _calcium.delete_doubleArray
    __del__ = lambda self : None;
    def __getitem__(self, *args):
        """__getitem__(self, size_t index) -> double"""
        return _calcium.doubleArray___getitem__(self, *args)

    def __setitem__(self, *args):
        """__setitem__(self, size_t index, double value)"""
        return _calcium.doubleArray___setitem__(self, *args)

    def cast(self):
        """cast(self) -> double"""
        return _calcium.doubleArray_cast(self)

    def frompointer(*args):
        """frompointer(double t) -> doubleArray"""
        return _calcium.doubleArray_frompointer(*args)

    if _newclass:frompointer = staticmethod(frompointer)
    __swig_getmethods__["frompointer"] = lambda x: frompointer
doubleArray_swigregister = _calcium.doubleArray_swigregister
doubleArray_swigregister(doubleArray)

def doubleArray_frompointer(*args):
  """doubleArray_frompointer(double t) -> doubleArray"""
  return _calcium.doubleArray_frompointer(*args)

class stringArray(_object):
    """Proxy of C++ stringArray class"""
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, stringArray, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, stringArray, name)
    __repr__ = _swig_repr
    def __init__(self, *args): 
        """
        __init__(self, int nelements, int size = 0) -> stringArray
        __init__(self, int nelements) -> stringArray
        """
        this = _calcium.new_stringArray(*args)
        try: self.this.append(this)
        except: self.this = this
    __swig_destroy__ = _calcium.delete_stringArray
    __del__ = lambda self : None;
    def __getitem__(self, *args):
        """__getitem__(self, int index) -> char"""
        return _calcium.stringArray___getitem__(self, *args)

    def __setitem__(self, *args):
        """__setitem__(self, int index, char value)"""
        return _calcium.stringArray___setitem__(self, *args)

    __swig_setmethods__["data"] = _calcium.stringArray_data_set
    __swig_getmethods__["data"] = _calcium.stringArray_data_get
    if _newclass:data = _swig_property(_calcium.stringArray_data_get, _calcium.stringArray_data_set)
    __swig_setmethods__["nelem"] = _calcium.stringArray_nelem_set
    __swig_getmethods__["nelem"] = _calcium.stringArray_nelem_get
    if _newclass:nelem = _swig_property(_calcium.stringArray_nelem_get, _calcium.stringArray_nelem_set)
    __swig_setmethods__["size"] = _calcium.stringArray_size_set
    __swig_getmethods__["size"] = _calcium.stringArray_size_get
    if _newclass:size = _swig_property(_calcium.stringArray_size_get, _calcium.stringArray_size_set)
stringArray_swigregister = _calcium.stringArray_swigregister
stringArray_swigregister(stringArray)

class DSC(_object):
    """Proxy of C++ Engines::DSC class"""
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, DSC, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, DSC, name)
    __repr__ = _swig_repr
    AddingConnection = _calcium.DSC_AddingConnection
    RemovingConnection = _calcium.DSC_RemovingConnection
    ApplicationError = _calcium.DSC_ApplicationError
    def __init__(self): 
        """__init__(self) -> DSC"""
        this = _calcium.new_DSC()
        try: self.this.append(this)
        except: self.this = this
    __swig_destroy__ = _calcium.delete_DSC
    __del__ = lambda self : None;
DSC_swigregister = _calcium.DSC_swigregister
DSC_swigregister(DSC)

class PySupervCompo(_object):
    """Proxy of C++ PySupervCompo class"""
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, PySupervCompo, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, PySupervCompo, name)
    __repr__ = _swig_repr
    def __init__(self, *args): 
        """
        __init__(self, CORBA::ORB_ptr orb, PortableServer::POA_ptr poa, Engines::Container_ptr contai, 
            char instanceName, 
            char interfaceName) -> PySupervCompo
        """
        this = _calcium.new_PySupervCompo(*args)
        try: self.this.append(this)
        except: self.this = this
    __swig_destroy__ = _calcium.delete_PySupervCompo
    __del__ = lambda self : None;
    def init_service(self, *args):
        """init_service(self, char service_name) -> CORBA::Boolean"""
        return _calcium.PySupervCompo_init_service(self, *args)

    def create_provides_data_port(self, *args):
        """create_provides_data_port(self, char port_fab_type) -> provides_port"""
        return _calcium.PySupervCompo_create_provides_data_port(self, *args)

    def create_uses_data_port(self, *args):
        """create_uses_data_port(self, char port_fab_type) -> uses_port"""
        return _calcium.PySupervCompo_create_uses_data_port(self, *args)

    def add_port(self, *args):
        """
        add_port(self, char port_fab_type, char port_type, char port_name)
        add_port(self, provides_port port, char provides_port_name)
        add_port(self, uses_port port, char uses_port_name)
        """
        return _calcium.PySupervCompo_add_port(self, *args)

    def get_provides_port(self, *args):
        """get_provides_port(self, char provides_port_name, CORBA::Boolean connection_error) -> Ports::Port_ptr"""
        return _calcium.PySupervCompo_get_provides_port(self, *args)

    def connect_uses_port(self, *args):
        """connect_uses_port(self, char uses_port_name, Ports::Port_ptr provides_port_ref)"""
        return _calcium.PySupervCompo_connect_uses_port(self, *args)

    def connect_provides_port(self, *args):
        """connect_provides_port(self, char provides_port_name)"""
        return _calcium.PySupervCompo_connect_provides_port(self, *args)

    def disconnect_provides_port(self, *args):
        """disconnect_provides_port(self, char provides_port_name, Message message)"""
        return _calcium.PySupervCompo_disconnect_provides_port(self, *args)

    def disconnect_uses_port(self, *args):
        """
        disconnect_uses_port(self, char uses_port_name, Ports::Port_ptr provides_port_ref, 
            Message message)
        """
        return _calcium.PySupervCompo_disconnect_uses_port(self, *args)

    def get_port_properties(self, *args):
        """get_port_properties(self, char port_name) -> Ports::PortProperties_ptr"""
        return _calcium.PySupervCompo_get_port_properties(self, *args)

    def getInputFileToService(self, *args):
        """getInputFileToService(self, char service_name, char Salome_file_name) -> Engines::Salome_file_ptr"""
        return _calcium.PySupervCompo_getInputFileToService(self, *args)

    def checkInputFilesToService(self, *args):
        """checkInputFilesToService(self, char service_name)"""
        return _calcium.PySupervCompo_checkInputFilesToService(self, *args)

    def setInputFileToService(self, *args):
        """setInputFileToService(self, char service_name, char Salome_file_name) -> Engines::Salome_file_ptr"""
        return _calcium.PySupervCompo_setInputFileToService(self, *args)

    def getOutputFileToService(self, *args):
        """getOutputFileToService(self, char service_name, char Salome_file_name) -> Engines::Salome_file_ptr"""
        return _calcium.PySupervCompo_getOutputFileToService(self, *args)

    def checkOutputFilesToService(self, *args):
        """checkOutputFilesToService(self, char service_name)"""
        return _calcium.PySupervCompo_checkOutputFilesToService(self, *args)

    def setOutputFileToService(self, *args):
        """setOutputFileToService(self, char service_name, char Salome_file_name) -> Engines::Salome_file_ptr"""
        return _calcium.PySupervCompo_setOutputFileToService(self, *args)

    def add_provides_port(self, *args):
        """add_provides_port(self, Ports::Port_ptr ref, char provides_port_name, Ports::PortProperties_ptr port_prop)"""
        return _calcium.PySupervCompo_add_provides_port(self, *args)

    def add_uses_port(self, *args):
        """add_uses_port(self, char repository_id, char uses_port_name, Ports::PortProperties_ptr port_prop)"""
        return _calcium.PySupervCompo_add_uses_port(self, *args)

    def get_uses_port(self, *args):
        """get_uses_port(self, char uses_port_name) -> Engines::DSC::uses_port"""
        return _calcium.PySupervCompo_get_uses_port(self, *args)

    def is_connected(self, *args):
        """is_connected(self, char port_name) -> CORBA::Boolean"""
        return _calcium.PySupervCompo_is_connected(self, *args)

    def setTimeOut():
        """setTimeOut()"""
        return _calcium.PySupervCompo_setTimeOut()

    if _newclass:setTimeOut = staticmethod(setTimeOut)
    __swig_getmethods__["setTimeOut"] = lambda x: setTimeOut
    def ptr(self):
        """ptr(self) -> long"""
        return _calcium.PySupervCompo_ptr(self)

PySupervCompo_swigregister = _calcium.PySupervCompo_swigregister
PySupervCompo_swigregister(PySupervCompo)

def PySupervCompo_setTimeOut():
  """PySupervCompo_setTimeOut()"""
  return _calcium.PySupervCompo_setTimeOut()


def create_calcium_port(*args):
  """
    create_calcium_port(Superv_Component_i compo, char name, char type, char mode, 
        char depend)
    """
  return _calcium.create_calcium_port(*args)
TRUE = _calcium.TRUE
FALSE = _calcium.FALSE
FORMAT_TEMPS = _calcium.FORMAT_TEMPS
EPSILON = _calcium.EPSILON
VERSION_LEN = _calcium.VERSION_LEN
CODE_LEN = _calcium.CODE_LEN
VARIABLE_LEN = _calcium.VARIABLE_LEN
INSTANCE_LEN = _calcium.INSTANCE_LEN
DRIVER_LEN = _calcium.DRIVER_LEN
ARCHI_LEN = _calcium.ARCHI_LEN
ENV_VAR_LEN = _calcium.ENV_VAR_LEN
ACCC_LEN = _calcium.ACCC_LEN
PVM_LEN = _calcium.PVM_LEN
USER_LEN = _calcium.USER_LEN
MACHINE_LEN = _calcium.MACHINE_LEN
COMMAND_LEN = _calcium.COMMAND_LEN
MAX_LEN = _calcium.MAX_LEN
FICHIER_LEN = _calcium.FICHIER_LEN
NB_LIGNE_ERREUR = _calcium.NB_LIGNE_ERREUR
NB_LIGNE_TRACE = _calcium.NB_LIGNE_TRACE
CP_NORMALE = _calcium.CP_NORMALE
CP_ANORMALE = _calcium.CP_ANORMALE
CP_CONT = _calcium.CP_CONT
CP_ARRET = _calcium.CP_ARRET
CP_INITIAL = _calcium.CP_INITIAL
CP_NON_CONNECTE = _calcium.CP_NON_CONNECTE
CP_ATTENTE = _calcium.CP_ATTENTE
CP_EXECUTION = _calcium.CP_EXECUTION
CP_DECONNECTE = _calcium.CP_DECONNECTE
CP_TERMINE = _calcium.CP_TERMINE
CP_ENTIER = _calcium.CP_ENTIER
CP_REEL = _calcium.CP_REEL
CP_DREEL = _calcium.CP_DREEL
CP_COMPLEXE = _calcium.CP_COMPLEXE
CP_LOGIQUE = _calcium.CP_LOGIQUE
CP_CHAINE = _calcium.CP_CHAINE
CP_TEMPS = _calcium.CP_TEMPS
CP_ITERATION = _calcium.CP_ITERATION
CP_SEQUENTIEL = _calcium.CP_SEQUENTIEL
CP_IN = _calcium.CP_IN
CP_OUT = _calcium.CP_OUT
CP_NORMAL = _calcium.CP_NORMAL
CP_ESPION = _calcium.CP_ESPION
CP_ILLIMITE = _calcium.CP_ILLIMITE
CP_AUTESP = _calcium.CP_AUTESP
CP_SANS = _calcium.CP_SANS
CP_SUCCINCT = _calcium.CP_SUCCINCT
CP_DETAILLE = _calcium.CP_DETAILLE
CP_PAUSE = _calcium.CP_PAUSE
CP_LINEAIRE = _calcium.CP_LINEAIRE
CP_ESCALIER = _calcium.CP_ESCALIER
TI = _calcium.TI
TF = _calcium.TF
CP_TOUTES = _calcium.CP_TOUTES
CP_AUCUNE = _calcium.CP_AUCUNE
CP_PAS = _calcium.CP_PAS
CP_ROUTE = _calcium.CP_ROUTE
CP_ERREURS = _calcium.CP_ERREURS
CP_ROUTE_NORMAL = _calcium.CP_ROUTE_NORMAL
CP_ROUTE_DIRECT = _calcium.CP_ROUTE_DIRECT
CP_AUTO = _calcium.CP_AUTO
CP_BLOCAGE = _calcium.CP_BLOCAGE
CP_MANUEL = _calcium.CP_MANUEL
CP_IMMEDIATE = _calcium.CP_IMMEDIATE
CPLVAV = _calcium.CPLVAV
CPLVAF = _calcium.CPLVAF
CPLVAS = _calcium.CPLVAS
CPLCAV = _calcium.CPLCAV
CPLFAV = _calcium.CPLFAV
ERREUR = _calcium.ERREUR
CONNEXION = _calcium.CONNEXION
EMISSION = _calcium.EMISSION
DECONNEXION = _calcium.DECONNEXION
LECTURE_VARIABLE = _calcium.LECTURE_VARIABLE
ECRITURE_VARIABLE = _calcium.ECRITURE_VARIABLE
FIN_DE_PAS = _calcium.FIN_DE_PAS
AUIN_FIN_DE_PAS = _calcium.AUIN_FIN_DE_PAS
EFFACEMENT = _calcium.EFFACEMENT
MODE_EXEC = _calcium.MODE_EXEC
RUN_N_PAS = _calcium.RUN_N_PAS
DEF_CODE = _calcium.DEF_CODE
DEF_INSTANCE = _calcium.DEF_INSTANCE
DEF_LIEN = _calcium.DEF_LIEN
DEM_VERSION = _calcium.DEM_VERSION
SET_OPTION = _calcium.SET_OPTION
DEM_OPTION = _calcium.DEM_OPTION
DEM_CODES = _calcium.DEM_CODES
DEM_INSTS_DE_CODE = _calcium.DEM_INSTS_DE_CODE
DEM_VARIABLES = _calcium.DEM_VARIABLES
DEM_VARS_DE_CODE = _calcium.DEM_VARS_DE_CODE
DEM_VARS_DE_INST = _calcium.DEM_VARS_DE_INST
DEM_CARS_DE_VARIABLE = _calcium.DEM_CARS_DE_VARIABLE
DEM_CARS_DE_LIEN = _calcium.DEM_CARS_DE_LIEN
ENV_VALEURS_VARIABLE = _calcium.ENV_VALEURS_VARIABLE
ENV_OPTION = _calcium.ENV_OPTION
ENV_CODES = _calcium.ENV_CODES
ENV_INSTS_DE_CODE = _calcium.ENV_INSTS_DE_CODE
ENV_VARIABLES = _calcium.ENV_VARIABLES
ENV_VARS_DE_CODE = _calcium.ENV_VARS_DE_CODE
ENV_VARS_DE_INST = _calcium.ENV_VARS_DE_INST
ENV_CARS_DE_VARIABLE = _calcium.ENV_CARS_DE_VARIABLE
ENV_CARS_DE_LIEN = _calcium.ENV_CARS_DE_LIEN
ENV_TOPOLOGY = _calcium.ENV_TOPOLOGY
R_ENV_TOPOLOGY = _calcium.R_ENV_TOPOLOGY
ENV_MACHINE = _calcium.ENV_MACHINE
R_ENV_MACHINE = _calcium.R_ENV_MACHINE
ENV_CODE = _calcium.ENV_CODE
R_ENV_CODE = _calcium.R_ENV_CODE
ENV_INSTANCE = _calcium.ENV_INSTANCE
R_ENV_INSTANCE = _calcium.R_ENV_INSTANCE
ENV_VAR = _calcium.ENV_VAR
R_ENV_VAR = _calcium.R_ENV_VAR
ENV_LIEN = _calcium.ENV_LIEN
R_ENV_LIEN = _calcium.R_ENV_LIEN
ENV_ATTRIBUTS = _calcium.ENV_ATTRIBUTS
R_ENV_ATTRIBUTS = _calcium.R_ENV_ATTRIBUTS
ENV_VDATA = _calcium.ENV_VDATA
R_ENV_VDATA = _calcium.R_ENV_VDATA
P_HOST_DELETE = _calcium.P_HOST_DELETE
P_TASK_EXIT = _calcium.P_TASK_EXIT
CPOK = _calcium.CPOK
CPERIU = _calcium.CPERIU
CPNMVR = _calcium.CPNMVR
CPIOVR = _calcium.CPIOVR
CPTP = _calcium.CPTP
CPTPVR = _calcium.CPTPVR
CPIT = _calcium.CPIT
CPITVR = _calcium.CPITVR
CPRENA = _calcium.CPRENA
CPDNTP = _calcium.CPDNTP
CPDNDI = _calcium.CPDNDI
CPNMCD = _calcium.CPNMCD
CPNMIN = _calcium.CPNMIN
CPATTENTE = _calcium.CPATTENTE
CPBLOC = _calcium.CPBLOC
CPNTNULL = _calcium.CPNTNULL
CPLGVR = _calcium.CPLGVR
CPSTOP = _calcium.CPSTOP
CPATAL = _calcium.CPATAL
CPNOCP = _calcium.CPNOCP
CPCTVR = _calcium.CPCTVR
CPPASNULL = _calcium.CPPASNULL
CPMACHINE = _calcium.CPMACHINE
CPGRNU = _calcium.CPGRNU
CPGRIN = _calcium.CPGRIN
CPFINFICH = _calcium.CPFINFICH
CPERRFICH = _calcium.CPERRFICH
CPNORERR = _calcium.CPNORERR
CPRUNERR = _calcium.CPRUNERR
CPOPT = _calcium.CPOPT
CPVALOPT = _calcium.CPVALOPT
CPECREFF = _calcium.CPECREFF
CPLIEN = _calcium.CPLIEN
CPINARRET = _calcium.CPINARRET
CPSTOPSEQ = _calcium.CPSTOPSEQ
CPDECL = _calcium.CPDECL
CPINEXEC = _calcium.CPINEXEC
CPPVM = _calcium.CPPVM
CPERRINST = _calcium.CPERRINST
CPMODE = _calcium.CPMODE
CPINSTDEC = _calcium.CPINSTDEC
DEBUT_COUPLAGE = _calcium.DEBUT_COUPLAGE
FIN_COUPLAGE = _calcium.FIN_COUPLAGE
EXEC = _calcium.EXEC
CPCD = _calcium.CPCD
CPALLOW = _calcium.CPALLOW
CPECRI = _calcium.CPECRI
DEB_LECT = _calcium.DEB_LECT
FIN_LECT = _calcium.FIN_LECT
CPFIN = _calcium.CPFIN
CPFINP = _calcium.CPFINP
CPAUFP = _calcium.CPAUFP
CPINFP = _calcium.CPINFP
CPEFF = _calcium.CPEFF
STOP = _calcium.STOP
BLOCAGE = _calcium.BLOCAGE
CPPAUSE = _calcium.CPPAUSE
CPNORMAL = _calcium.CPNORMAL
CPNPAS = _calcium.CPNPAS
CPADCD = _calcium.CPADCD
CPADINCD = _calcium.CPADINCD
CPADLN = _calcium.CPADLN
CPIVERS = _calcium.CPIVERS
CPICD = _calcium.CPICD
CPIINCD = _calcium.CPIINCD
CPIVR = _calcium.CPIVR
CPIVRCD = _calcium.CPIVRCD
CPIVRIN = _calcium.CPIVRIN
CPICAVR = _calcium.CPICAVR
CPIILIEN = _calcium.CPIILIEN
CPSETOPT = _calcium.CPSETOPT
CPGETOPT = _calcium.CPGETOPT
TASK_EXIT = _calcium.TASK_EXIT
HOST_DELETE = _calcium.HOST_DELETE
ENTIER = _calcium.ENTIER
REEL = _calcium.REEL
DREEL = _calcium.DREEL
COMPLEXE = _calcium.COMPLEXE
LOGIQUE = _calcium.LOGIQUE
CHAINE = _calcium.CHAINE

def cp_cd(*args):
  """cp_cd(Superv_Component_i component) -> int"""
  return _calcium.cp_cd(*args)

def cp_een(*args):
  """
    cp_een(Superv_Component_i component, int dep, float t, int n, 
        char nom, int nval, int eval) -> int
    """
  return _calcium.cp_een(*args)

def cp_edb(*args):
  """
    cp_edb(Superv_Component_i component, int dep, double t, int n, 
        char nom, int nval, double eval) -> int
    """
  return _calcium.cp_edb(*args)

def cp_ere(*args):
  """
    cp_ere(Superv_Component_i component, int dep, float t, int n, 
        char nom, int nval, float eval) -> int
    """
  return _calcium.cp_ere(*args)

def cp_ecp(*args):
  """
    cp_ecp(Superv_Component_i component, int dep, float t, int n, 
        char nom, int nval, float ecpval) -> int
    """
  return _calcium.cp_ecp(*args)

def cp_elo(*args):
  """
    cp_elo(Superv_Component_i component, int dep, float t, int n, 
        char nom, int nval, int eval) -> int
    """
  return _calcium.cp_elo(*args)

def cp_ech(*args):
  """
    cp_ech(Superv_Component_i component, int dep, float t, int n, 
        char nom, int nval, char eval) -> int
    """
  return _calcium.cp_ech(*args)

def cp_elg(*args):
  """
    cp_elg(Superv_Component_i component, int dep, float t, int n, 
        char nom, int nval, long eval) -> int
    """
  return _calcium.cp_elg(*args)

def cp_eln(*args):
  """
    cp_eln(Superv_Component_i component, int dep, float t, int n, 
        char nom, int nval, long eval) -> int
    """
  return _calcium.cp_eln(*args)

def cp_len(*args):
  """
    cp_len(Superv_Component_i component, int dep, float ti, float tf, 
        int niter, char nom, int nmax, int lval) -> int
    """
  return _calcium.cp_len(*args)

def cp_ldb(*args):
  """
    cp_ldb(Superv_Component_i component, int dep, double ti, double tf, 
        int niter, char nom, int nmax, double lval) -> int
    """
  return _calcium.cp_ldb(*args)

def cp_lre(*args):
  """
    cp_lre(Superv_Component_i component, int dep, float ti, float tf, 
        int niter, char nom, int nmax, float lval) -> int
    """
  return _calcium.cp_lre(*args)

def cp_lcp(*args):
  """
    cp_lcp(Superv_Component_i component, int dep, float ti, float tf, 
        int niter, char nom, int nmax, float lcpval) -> int
    """
  return _calcium.cp_lcp(*args)

def cp_llo(*args):
  """
    cp_llo(Superv_Component_i component, int dep, float ti, float tf, 
        int niter, char nom, int nmax, int lval) -> int
    """
  return _calcium.cp_llo(*args)

def cp_lch(*args):
  """
    cp_lch(Superv_Component_i component, int dep, float ti, float tf, 
        int niter, char nom, int nmax, char lval) -> int
    """
  return _calcium.cp_lch(*args)

def cp_llg(*args):
  """
    cp_llg(Superv_Component_i component, int dep, float ti, float tf, 
        int niter, char nom, int nmax, long lval) -> int
    """
  return _calcium.cp_llg(*args)

def cp_lln(*args):
  """
    cp_lln(Superv_Component_i component, int dep, float ti, float tf, 
        int niter, char nom, int nmax, long lval) -> int
    """
  return _calcium.cp_lln(*args)

def cp_fini(*args):
  """cp_fini(Superv_Component_i component, char nom, int n) -> int"""
  return _calcium.cp_fini(*args)

def cp_fint(*args):
  """cp_fint(Superv_Component_i component, char nom, float t) -> int"""
  return _calcium.cp_fint(*args)

def cp_effi(*args):
  """cp_effi(Superv_Component_i component, char nom, int n) -> int"""
  return _calcium.cp_effi(*args)

def cp_efft(*args):
  """cp_efft(Superv_Component_i component, char nom, float t) -> int"""
  return _calcium.cp_efft(*args)

def cp_fin(*args):
  """cp_fin(Superv_Component_i component, int cp_end) -> int"""
  return _calcium.cp_fin(*args)





# -*- coding: iso-8859-1 -*-
# Copyright (C) 2007-2012  CEA/DEN, EDF R&D, OPEN CASCADE
#
# Copyright (C) 2003-2007  OPEN CASCADE, EADS/CCR, LIP6, CEA/DEN,
# CEDRAT, EDF R&D, LEG, PRINCIPIA R&D, BUREAU VERITAS
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# See http://www.salome-platform.org/ or email : webmaster.salome@opencascade.com
#

__author__="gboulant"
__date__ ="$17 avr. 2010 19:44:36$"

from enumerate import Enumerate
from datamodeler import DataModeler, TypeString, TypeInteger
from salome.kernel import Callable

class TestData(DataModeler):
    """
    This class is the placeholder for meta data associated to a study case.
    The meta-data are used for organisation and indexing purposes
    """
    TYPES_LIST=Enumerate([
        'SEP',
        'OTHER'
    ])

    def __init__(self):
        DataModeler.__init__(self)
        self.addAttribute(
            name  = "NAME",
            type  = TypeString,
            range = None
            )
        self.addAttribute(
            name  = "TYPE",
            type  = TypeInteger,
            range = self.TYPES_LIST.listvalues()
            )

    def setName(self, value):
        self.NAME = value

    def getName(self):
        return self.NAME

    def setType(self, value):
        self.TYPE = value

    def getType(self):
        return self.TYPE

    def getDefault():
        """
        Create a default instance of TestData
        @class-method
        """
        testdata = TestData()
        testdata.NAME = "my case"
        testdata.TYPE = TestData.TYPES_LIST.SEP
        return testdata

    getDefault = Callable(getDefault)
#
# ==============================================================================
# Basic use cases and unit tests
# ==============================================================================
#
from uiexception import UiException

def TEST_getName():
    testdata = TestData()
    testdata.setName("Sous-epaisseur")
    testdata.setType(TestData.TYPES_LIST.SEP)
    if ( testdata.NAME != "Sous-epaisseur" ):
        return False
    return True


def TEST_useBadKey():
    testdata = TestData()
    try:
        testdata.unknown = "unknown"
        # This should not arrive here
        return False
    except UiException, err:
        print err
        return True

def TEST_useBadType():
    testdata = TestData()
    try:
        testdata.TYPE = "unknown"
        # This should not arrive here
        return False
    except UiException, err:
        print err
        return True

def TEST_useBadRange():
    testdata = TestData()

    try:
        testdata.TYPE = TestData.TYPES_LIST.SEP
        testdata.setType(TestData.TYPES_LIST.SEP)
        # This should arrive here
    except UiException, err:
        # And not here
        print err
        return False

    try:
        testdata.TYPE = 9999 # a type that does not exist in the range
        # This should not arrive here
        return False
    except UiException, err:
        print err
        return True

def TEST_serialize():
    import salome.kernel
    ref_testdata = TestData()
    ref_testdata.setName("The firts name")
    res_testdata = salome.kernel.unserialize(salome.kernel.serialize(ref_testdata))

    print res_testdata.getName()

    if res_testdata.getName() != ref_testdata.getName():
        return False

    # Is the unserialized data still functional?
    try:
        res_testdata.setName("An other name")
        print res_testdata.getName()
    except:
        print e
        return False
    return True

if __name__ == "__main__":
    from unittester import run
    run("salome/kernel/testdata","TEST_getName")
    run("salome/kernel/testdata","TEST_useBadKey")
    run("salome/kernel/testdata","TEST_useBadType")
    run("salome/kernel/testdata","TEST_useBadRange")
    run("salome/kernel/testdata","TEST_serialize")



# -*- coding: iso-8859-1 -*-
# Copyright (C) 2010-2012  CEA/DEN, EDF R&D, OPEN CASCADE
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# See http://www.salome-platform.org/ or email : webmaster.salome@opencascade.com
#

__author__="gboulant"
__date__ ="$15 avr. 2010 19:44:17$"

from uiexception import DevelException

# Most usable class types
TypeString= "".__class__
__ref_integer = 0
TypeInteger = __ref_integer.__class__
__ref_double = 0.0
TypeDouble = __ref_double.__class__
__ref_list = []
TypeList = __ref_list.__class__
__ref_dict = {}
TypeDictionnary = __ref_dict.__class__

# There is no control to do for these attributes. They are attributes for the
# class management and not data of the model.
UNCHECKED_ATTRIBUTES = [
    "_typemap",
    "_rangemap",
    "_defaultmap",
    "_voidmap"
]

class DataModeler:
    """
    This class is a placeholder for modeling data. An object based on this class
    (particular instance or specialized derived class) can defined attributes with
    the following properties:

    - a type : the class or the type of the attribute. Setting an attribute to
      a value whose type is not the specified type raises an exception.
    - a range : a list of the possible values for the attribute. Setting an
      attribute to a value not in the range raises an exception
    - a default: the default value of an attribute when an instance is created
    - a void flag: the attribute can be authorized to be None or not using this
      flag. Setting an attribute to a None value while the flag is not set to
      True raises an exception. By default, a None value is not allowed.

    These properties are dictionnaries mapping the attribute name to its
    associated value for the property.

    A typical usage is to derived this class in a specialized form where the
    attributes names and there properties are defined in the constructor. See
    use cases at the end of this file.

    """
    def __init__(self, typemap=None, rangemap=None, defaultmap=None, voidmap=None):
        self._typemap = {}
        self._rangemap   = {} # possible values
        self._defaultmap = {} # defaults values
        self._voidmap    = {}    # None values are allowed
        
        if typemap is not None:
            self._typemap.update(typemap)
        if rangemap is not None:
            self._rangemap.update(rangemap)
        if voidmap is not None:
            self._voidmap.update(voidmap)

        # Default initialization (if any)
        if defaultmap is not None:
            self._defaultmap.update(defaultmap)
            for name in self._defaultmap.keys():
                self.__setattr__(name,self._defaultmap[name])

    def addAttribute(self, name, type=None, range=None, default=None, void=None):
        """
        A None argument means that no entry is created in the associated maps.
        """
        self._typemap[name] = type

        if range is not None:
            self._rangemap[name] = range

        if void is not None:
            self._voidmap[name] = void

        if (not void) and (default is None):
            return
        
        self.__setattr__(name,default)

    def __setattr__(self, name, val):
        if name in UNCHECKED_ATTRIBUTES:
            self.__dict__[name] = val
            return

        #__GBO_DEBUG_
        if name == "_typemap":
            print "WARNING WARNING WARNING : changing value of _typemap by ",val

        if name not in self._typemap.keys():
            raise DevelException("The class "+str(self.__class__)+" has no attribute "+str(name))

        if val is None:
            if not self.__isVoidAllowed(name):
                raise DevelException("The attribute "+str(name)+" can't be None")
            else:
                # We can stop here and set the value to None
                self.__dict__[name] = None
                return

        if self.__isNotValidType(name,val):
            raise DevelException("The attribute "+str(name)+" must be an instance of "+str(self._typemap[name]))

        if self.__isNotValidRange(name,val):
            raise DevelException("The attribute "+str(name)+" must be a value in :"+str(self._rangemap[name]))

        self.__dict__[name] = val
    
    def __getattribute__(self, name):
        if name in UNCHECKED_ATTRIBUTES:
            return self.__dict__[name]

        if name not in self._typemap.keys():
            raise DevelException("The class "+str(self.__class__)+" has no attribute "+str(name))
        # The attribute coulb be requested while it has not been created yet (for
        # example if we did't call the setter before).
        if not self.__dict__.has_key(name):
            return None
        
        return self.__dict__[name]

    def __isNotValidType(self, name, val):
        isNotValid = (
            ( self._typemap[name] is not None) and
            ( not isinstance(val,self._typemap[name]) ) )

        return isNotValid

    def __isNotValidRange(self, name, val):
        isNotValid = (
            ( self._rangemap is not None) and
            ( self._rangemap.has_key(name) ) and
            ( self._rangemap[name] is not None ) and
            ( val not in self._rangemap[name] ) )

        return isNotValid

    def __isVoidAllowed(self,name):
        isVoidAllowed = (
            ( self._voidmap is not None) and
            ( self._voidmap.has_key(name) ) and
            ( self._voidmap[name] is True ) )
            
        return isVoidAllowed

    def log(self):
        print "DATAMODELER ["+str(self.__class__)+"]: self._typemap.keys() = "+str(self._typemap.keys())




#
# ==============================================================================
# Basic use cases and unit tests
# ==============================================================================
#
def TEST_usecase():
    typemap={}
    typemap["stringdata"] = TypeString
    typemap["integerdata"] = TypeInteger
    typemap["anydata"] = None # can be anything

    data = DataModeler(typemap)

    sdata = "toto"
    idata = 3
    data.stringdata = sdata
    data.integerdata = idata

    data.anydata = 5.3
    data.anydata = "any value"
    data.anydata = True

    print data.integerdata
    return True

def TEST_addAttribute():
    typemap={}
    typemap["stringdata"] = TypeString
    typemap["integerdata"] = TypeInteger
    data = DataModeler(typemap)
    data.stringdata = "a string value"

    ref_value = 1.3
    data.addAttribute(
        name    = "myAttr",
        type    = TypeDouble,
        range   = None,
        default = ref_value,
        void    = False)

    try:
        if data.myAttr != ref_value:
            return False
        data.myAttr = 5.3
        #data.myAttr = 5
    except Exception, e:
        print e
        return False

    try:
        data.myAttr = "bad type value"
        return False
    except Exception, e:
        print e
        return True

def TEST_badAttributeName():
    map={}
    map["stringdata"] = TypeString
    map["integerdata"] = TypeInteger

    data = DataModeler(map)

    # this should raise an exception
    try:
        data.myatt = 3
        return False
    except Exception, e:
        print "OK : "+str(e)
        return True

def TEST_badAttributeType():
    map={}
    map["stringdata"] = TypeString
    map["integerdata"] = TypeInteger

    data = DataModeler(map)
    # this should raise an exception
    try:
        data.stringdata = 2
        return False
    except Exception, e:
        print "OK : "+str(e)
        return True

def TEST_badAttributeRange():
    map={}
    map["stringdata"] = TypeString
    map["integerdata"] = TypeInteger

    range={}
    ref_integervalue = 3
    range["integerdata"] = [1,ref_integervalue,7]

    data = DataModeler(map,range)
    # this should not raise an exception
    try:
        data.integerdata = ref_integervalue
        data.stringdata = "anything (no restriction has been defined)"
    except Exception, e:
        print e
        return False

    # this should raise an exception
    try:
        data.integerdata = 9999 # a value not in the range
        return False
    except Exception, e:
        print e
        return True

def TEST_voidAttributeAllowed():
    map={}
    map["stringdata"] = TypeString
    map["integerdata"] = TypeInteger

    voidmap={}
    voidmap["stringdata"] = True

    data = DataModeler(typemap=map,voidmap=voidmap)
    try:
        # this should not raise an exception
        data.stringdata = None
        print data.stringdata
    except Exception, e:
        print e
        return False
    
    try:
        # this should raise an exception
        data.integerdata = None
        return False
    except Exception, e:
        print e
        return True

def TEST_defaultValues():
    typemap={}
    typemap["stringdata"] = TypeString
    typemap["integerdata"] = TypeInteger

    ref_value = "my initial value"
    defaultmap={}
    defaultmap["stringdata"] = ref_value

    data = DataModeler(typemap=typemap,defaultmap=defaultmap)
    print data.stringdata
    if data.stringdata != ref_value:
        return False
    else:
        return True

if __name__ == "__main__":
    from unittester import run
    run("salome/kernel/datamodeler","TEST_usecase")
    run("salome/kernel/datamodeler","TEST_addAttribute")
    run("salome/kernel/datamodeler","TEST_badAttributeName")
    run("salome/kernel/datamodeler","TEST_badAttributeType")
    run("salome/kernel/datamodeler","TEST_badAttributeRange")
    run("salome/kernel/datamodeler","TEST_voidAttributeAllowed")
    run("salome/kernel/datamodeler","TEST_defaultValues")



#!/usr/bin/env python
# Copyright (C) 2007-2012  CEA/DEN, EDF R&D, OPEN CASCADE
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# See http://www.salome-platform.org/ or email : webmaster.salome@opencascade.com
#

import sys, re
outfile = open(sys.argv[1], 'wb')
isCom = False
for line in open(sys.argv[2], 'rb').readlines():
    if re.match('class '+sys.argv[3]+'DC', line): 
        continue
    n = line.find('"""')
    n1 = line[(n+2):].find('"""')
    if (n > -1) and (n1 > -1):
        continue
    if isCom:
        if n > -1:
            isCom = False
        continue
    else:
        if n > -1:
            isCom = True
            continue       
    line = re.sub(r'^\s+#', '#', line) 
    line = re.sub(r'^\s+def', 'def', line) 
    line = re.sub(sys.argv[3]+'DC', sys.argv[3], line)
    outfile.write(line)
outfile.close()


#  -*- coding: iso-8859-1 -*-
# Copyright (C) 2007-2012  CEA/DEN, EDF R&D, OPEN CASCADE
#
# Copyright (C) 2003-2007  OPEN CASCADE, EADS/CCR, LIP6, CEA/DEN,
# CEDRAT, EDF R&D, LEG, PRINCIPIA R&D, BUREAU VERITAS
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# See http://www.salome-platform.org/ or email : webmaster.salome@opencascade.com
#

"""Create a virtual Salome installation

Based on a script created by Ian Bicking.

Typical use::

  python virtual_salome.py -v --prefix="." --module=/local/chris/SALOME2/RELEASES/Install/KERNEL_V3_1_0b1

install module KERNEL in the current directory
"""

import sys, os, optparse, shutil,glob,fnmatch
py_version = 'python%s.%s' % (sys.version_info[0], sys.version_info[1])

verbose=0

# -----------------------------------------------------------------------------

def mkdir(path):
    """Create a directory and all the intermediate directories if path does not exist"""
    if not os.path.exists(path):
        if verbose:
            print 'Creating %s' % path
        os.makedirs(path)
    else:
        if verbose:
            print 'Directory %s already exists' % path
            pass
        pass

# -----------------------------------------------------------------------------

def symlink(src, dest):
    """Create a link if it does not exist"""
    if not os.path.exists(dest):
        if os.path.lexists(dest):
            print "Do not create symlink %s. It already exists but it's broken" % dest
            return
        if verbose:
            print 'Creating symlink %s' % dest
            pass
        os.symlink(src, dest)
    else:
        if verbose:
            print 'Symlink %s already exists' % dest
        pass
    pass

# -----------------------------------------------------------------------------

def rmtree(dir):
    """Remove (recursive) a directory if it exists"""
    if os.path.exists(dir):
        print 'Deleting tree %s' % dir
        shutil.rmtree(dir)
    else:
        if verbose:
            print 'Do not need to delete %s; already gone' % dir
            pass
        pass
    pass

# -----------------------------------------------------------------------------

__lib__dir__ = None
def get_lib_dir():
    global __lib__dir__
    if __lib__dir__: return __lib__dir__
    import platform
    __lib__dir__ = "lib"
    return __lib__dir__

# -----------------------------------------------------------------------------

def link_module(options):
    global verbose

    if not options.module:
        print "Option module is mandatory"
        return

    module_dir=os.path.abspath(options.module)
    if not os.path.exists(module_dir):
        print "Module %s does not exist" % module_dir
        return

    verbose = options.verbose

    home_dir = os.path.expanduser(options.prefix)
    #try to find python version of salome application and put it in versio
    pys=[os.path.split(s)[1] for s in glob.glob(os.path.join(home_dir,get_lib_dir(),"python*.*"))]
    if not pys :
      versio=None
    else:
      versio=pys[0]

    pys=[os.path.split(s)[1] for s in glob.glob(os.path.join(module_dir,get_lib_dir(),"python*.*"))]
    #check if the module has a python version compatible with application version
    if not pys :
      pyversio=versio or py_version
    elif versio is None:
      pyversio=pys[0]
    elif versio in pys:
      pyversio=versio
    else:
      #incompatible python versions
      print "incompatible python versions : application has version %s and module %s has not" % (versio,module_dir)
      return

    module_bin_dir=os.path.join(module_dir,'bin','salome')
    module_idl_dir=os.path.join(module_dir,'idl','salome')
    module_lib_dir=os.path.join(module_dir,get_lib_dir(),'salome')
    module_lib_py_dir=os.path.join(module_dir,get_lib_dir(),pyversio,'site-packages','salome')
    module_lib_py_shared_dir=os.path.join(module_dir,get_lib_dir(),pyversio,
                                          'site-packages','salome','shared_modules')
    module_share_dir=os.path.join(module_dir,'share','salome')
    module_doc_gui_dir=os.path.join(module_dir,'doc','salome','gui')
    module_doc_tui_dir=os.path.join(module_dir,'doc','salome','tui')
    module_doc_dir=os.path.join(module_dir,'doc','salome')
    module_sharedoc_dir=os.path.join(module_dir,'share','doc','salome')
    module_sharedoc_gui_dir=os.path.join(module_dir,'share','doc','salome','gui')
    module_sharedoc_tui_dir=os.path.join(module_dir,'share','doc','salome','tui')

    bin_dir=os.path.join(home_dir,'bin','salome')
    idl_dir=os.path.join(home_dir,'idl','salome')
    lib_dir=os.path.join(home_dir,'lib','salome')
    lib_py_dir=os.path.join(home_dir,'lib',pyversio,'site-packages','salome')
    lib_py_shared_dir=os.path.join(home_dir,'lib',pyversio,
                                   'site-packages','salome','shared_modules')
    share_dir=os.path.join(home_dir,'share','salome')
    doc_gui_dir=os.path.join(home_dir,'doc','salome','gui')
    doc_tui_dir=os.path.join(home_dir,'doc','salome','tui')
    doc_dir=os.path.join(home_dir,'doc','salome')
    sharedoc_dir=os.path.join(home_dir,'share','doc','salome')
    sharedoc_gui_dir=os.path.join(home_dir,'share','doc','salome','gui')
    sharedoc_tui_dir=os.path.join(home_dir,'share','doc','salome','tui')

    if options.clear:
        rmtree(bin_dir)
        rmtree(idl_dir)
        rmtree(lib_dir)
        rmtree(lib_py_dir)
        rmtree(share_dir)
        rmtree(doc_dir)
        rmtree(sharedoc_dir)
        pass

    #directory bin/salome : create it and link content
    if os.path.exists(module_bin_dir):
        mkdir(bin_dir)
        for fn in os.listdir(module_bin_dir):
            symlink(os.path.join(module_bin_dir, fn), os.path.join(bin_dir, fn))
            pass
        pass
    else:
        if verbose:
            print module_bin_dir, " doesn't exist"
        pass

    #directory idl/salome : create it and link content
    if os.path.exists(module_idl_dir):
        mkdir(idl_dir)
        for fn in os.listdir(module_idl_dir):
            symlink(os.path.join(module_idl_dir, fn), os.path.join(idl_dir, fn))
    else:
        if verbose:
            print module_idl_dir, " doesn't exist"

    #directory lib/salome : create it and link content
    if os.path.exists(module_lib_dir):
        mkdir(lib_dir)
        for fn in os.listdir(module_lib_dir):
            symlink(os.path.join(module_lib_dir, fn), os.path.join(lib_dir, fn))
            pass
        pass
    else:
        if verbose:
            print module_lib_dir, " doesn't exist"
        pass

    #directory lib/pyversio/site-packages/salome : create it and link content
    if not os.path.exists(module_lib_py_dir):
        print "Python directory %s does not exist" % module_lib_py_dir
    else:
        # Specific action for the package salome
        module_lib_pypkg_dir=os.path.join(module_lib_py_dir,"salome")
        lib_pypkg_dir=os.path.join(lib_py_dir,"salome")
        mkdir(lib_pypkg_dir)
        mkdir(lib_py_shared_dir)
        for fn in os.listdir(module_lib_py_dir):
            if fn == "shared_modules": continue
            if fn == "salome": continue
            symlink(os.path.join(module_lib_py_dir, fn), os.path.join(lib_py_dir, fn))
            pass
        if os.path.exists(module_lib_py_shared_dir):
            for fn in os.listdir(module_lib_py_shared_dir):
                symlink(os.path.join(module_lib_py_shared_dir, fn), os.path.join(lib_py_shared_dir, fn))
                pass
            pass
        if os.path.exists(module_lib_pypkg_dir):
            for fn in os.listdir(module_lib_pypkg_dir):
                symlink(os.path.join(module_lib_pypkg_dir, fn), os.path.join(lib_pypkg_dir, fn))
                pass
            pass
        else:
            if verbose:
                print module_lib_py_shared_dir, " doesn't exist"
            pass

    #directory share/doc/salome (KERNEL doc) : create it and link content
    if os.path.exists(module_sharedoc_dir):
        mkdir(sharedoc_dir)
        for fn in os.listdir(module_sharedoc_dir):
            if fn == 'gui':continue
            if fn == 'tui':continue
            symlink(os.path.join(module_sharedoc_dir, fn), os.path.join(sharedoc_dir, fn))
            pass
        pass

    #directory share/doc/salome/gui : create it and link content
    if os.path.exists(module_sharedoc_gui_dir):
        mkdir(sharedoc_gui_dir)
        for fn in os.listdir(module_sharedoc_gui_dir):
            symlink(os.path.join(module_sharedoc_gui_dir, fn), os.path.join(sharedoc_gui_dir, fn))
            pass
        pass

    #directory share/doc/salome/tui : create it and link content
    if os.path.exists(module_sharedoc_tui_dir):
        mkdir(sharedoc_tui_dir)
        for fn in os.listdir(module_sharedoc_tui_dir):
            symlink(os.path.join(module_sharedoc_tui_dir, fn), os.path.join(sharedoc_tui_dir, fn))
            pass
        pass

    #directory share/salome : create it and link content
    if os.path.exists(module_share_dir):
        mkdir(share_dir)
        for fn in os.listdir(module_share_dir):
            if fn in ["resources","plugins"] :
                # Create the directory and then link the content
                mkdir(os.path.join(share_dir,fn))
                for ffn in os.listdir(os.path.join(module_share_dir,fn)):
                    symlink(os.path.join(module_share_dir, fn, ffn), os.path.join(share_dir,fn, ffn))
            else:
                #other directories (not resources)
                symlink(os.path.join(module_share_dir, fn), os.path.join(share_dir, fn))
    else:
        print "share/salome directory %s does not exist" % module_share_dir
        pass

    #html files in doc/salome directory
    if os.path.exists(module_doc_dir):
        mkdir(doc_dir)
        for fn in os.listdir(module_doc_dir):
            if fn == 'gui':continue
            if fn == 'tui':continue
            symlink(os.path.join(module_doc_dir, fn), os.path.join(doc_dir, fn))
            pass
        pass

    #directory doc/salome/gui : create it and link content
    if os.path.exists(module_doc_gui_dir):
        mkdir(doc_gui_dir)
        for fn in os.listdir(module_doc_gui_dir):
            symlink(os.path.join(module_doc_gui_dir, fn), os.path.join(doc_gui_dir, fn))
            pass
        pass

    #directory doc/salome/tui : create it and link content
    if os.path.exists(module_doc_tui_dir):
        mkdir(doc_tui_dir)
        for fn in os.listdir(module_doc_tui_dir):
            symlink(os.path.join(module_doc_tui_dir, fn), os.path.join(doc_tui_dir, fn))
            pass
        pass

# -----------------------------------------------------------------------------

def main():
    usage="""usage: %prog [options]
Typical use is:
  python virtual_salome.py -v --prefix="." --module=/local/chris/SALOME2/RELEASES/Install/KERNEL_V3_1_0b1
"""
    parser = optparse.OptionParser(usage=usage)

    parser.add_option('-v', '--verbose', action='count', dest='verbose',
                      default=0, help="Increase verbosity")

    parser.add_option('--prefix', dest="prefix", default='.',
                      help="The base directory to install to (default .)")

    parser.add_option('--module', dest="module",
                      help="The module directory to install in (mandatory)")

    parser.add_option('--clear', dest='clear', action='store_true',
        help="Clear out the install and start from scratch")

    options, args = parser.parse_args()
    link_module(options)
    pass

# -----------------------------------------------------------------------------

if __name__ == '__main__':
    main()
    pass



#  -*- coding: iso-8859-1 -*-
# Copyright (C) 2007-2012  CEA/DEN, EDF R&D, OPEN CASCADE
#
# Copyright (C) 2003-2007  OPEN CASCADE, EADS/CCR, LIP6, CEA/DEN,
# CEDRAT, EDF R&D, LEG, PRINCIPIA R&D, BUREAU VERITAS
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# See http://www.salome-platform.org/ or email : webmaster.salome@opencascade.com
#

#  File   : TestLifeCycleCORBA_SWIG.py
#  Author : Paul RASCLE, EDF
#  Module : SALOME
#  $Header: /home/server/cvs/KERNEL/KERNEL_SRC/src/LifeCycleCORBA_SWIG/Test/TestLifeCycleCORBA_SWIG.py,v 1.5.2.2.14.2.12.1 2012-04-12 14:05:16 vsr Exp $
#
import sys, os,signal,string,commands
import runSalome
import setenv
import orbmodule
import TestKiller
import addToKillList

# get SALOME environment :

args, modules_list, modules_root_dir = setenv.get_config()
setenv.set_env(args, modules_list, modules_root_dir)

# set environment for trace in logger
# (with file, servers may be killed before the write to the file...)

#os.environ["SALOME_trace"] = "file:/tmp/traceUnitTest.log"
#os.environ["SALOME_trace"] = "local"
os.environ["SALOME_trace"] = "with_logger"

# launch CORBA naming server

clt=orbmodule.client()

# launch CORBA logger server

myServer=runSalome.LoggerServer(args)
myServer.run()
clt.waitLogger("Logger")

# launch notify server

myServer=runSalome.NotifyServer(args,modules_root_dir)
myServer.run()

# launch registry server

myServer=runSalome.RegistryServer(args)
myServer.run()
clt.waitNS("/Registry")

# launch module catalog server

cataServer=runSalome.CatalogServer(args)
cataServer.setpath(modules_list,modules_root_dir)
cataServer.run()
clt.waitNS("/Kernel/ModulCatalog")

# launch container manager server

myCmServer = runSalome.LauncherServer(args)
myCmServer.setpath(modules_list,modules_root_dir)
myCmServer.run()
clt.waitNS("/SalomeLauncher")

# execute Unit Test

command = ['TestLifeCycleCORBA']
ret = os.spawnvp(os.P_WAIT, command[0], command)

import LifeCycleCORBA_SWIGTest
import unittest
unittest.TextTestRunner(verbosity=2).run(LifeCycleCORBA_SWIGTest.suite())

# kill containers created by the Container Manager

import Engines
launcher = clt.waitNS("/SalomeLauncher",Engines.SalomeLauncher)
launcher.Shutdown()

# kill Test process

addToKillList.killList()

TestKiller.killProcess(runSalome.process_id)



#!/usr/bin/env python
#  -*- coding: iso-8859-1 -*-
# Copyright (C) 2007-2012  CEA/DEN, EDF R&D, OPEN CASCADE
#
# Copyright (C) 2003-2007  OPEN CASCADE, EADS/CCR, LIP6, CEA/DEN,
# CEDRAT, EDF R&D, LEG, PRINCIPIA R&D, BUREAU VERITAS
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# See http://www.salome-platform.org/ or email : webmaster.salome@opencascade.com
#

import os
import sys
#-------------------------------
# Python completion and others if you want
# You should have set PYTHONSTARTUP env variable
# or import user should try to import $HOME/.pythonrc.py
#-------------------------------
import user

#-------------------------------
# Get major CORBA objects
#-------------------------------
import CORBA
import CosNaming
# There are cyclic dependencies between Engines, SALOME and SALOMEDS.
# import first Engines, then SALOME and then SALOMEDS
# Or use reload(Engines) to be safe.
import Engines
import SALOME
import SALOMEDS
import SALOME_ModuleCatalog
reload(Engines)
reload(SALOME)
reload(SALOMEDS)
import salome_utils

import LifeCycleCORBA
import orbmodule
from runSalome import *

import Utils_Identity
files = glob.glob(os.path.join(os.environ["HOME"],Utils_Identity.getapplipath(),
                               "USERS",".omniORB_"+salome_utils.getUserName()+"_*.cfg"))

filename=""
if len(files)==1:
  filename=files[0]
else:
  print "You have %d sessions running" % len(files)
  for f in files:
     print "Session:",f
     rep= raw_input("Do you want to connect to this session [y|n]")
     if rep == "y":
        filename=f
        break
     
if filename != "":
  os.environ['OMNIORB_CONFIG']=filename
else:
  rep= raw_input("Do you want to try a local session on port 2810 ? [y|n]")
  if rep == "y":
     # Try a local session running on port 2810
     sys.argv=sys.argv+['-ORBInitRef','NameService=corbaname::localhost:2810']
  else:
     sys.exit(1)

print sys.argv

#direct adress from clt.orb.object_to_string(clt.rootContext)
#sys.argv=sys.argv+['-ORBInitRef','NameService=IOR:010000000100000000000000010000000000000023000000010100000a0000006c6f63616c686f737400fa0a0b0000004e616d6553657276696365']

class client(orbmodule.client):
   def initNS(self,args):
      # Obtain a reference to the root naming context
      obj         = self.orb.resolve_initial_references("NameService")
      try:
          self.rootContext = obj._narrow(CosNaming.NamingContext)
          return
      except (CORBA.TRANSIENT,CORBA.OBJECT_NOT_EXIST,CORBA.COMM_FAILURE):
          print "It's not a valid naming service"
          self.rootContext = None
          raise

clt=client()
print "Naming Service address: ",clt.orb.object_to_string(clt.rootContext)

clt.showNS()

session=clt.waitNS("/Kernel/Session")
catalog=clt.waitNS("/Kernel/ModulCatalog")
studyMgr=clt.waitNS("/myStudyManager")
import salome
salome.salome_init()
from salome import lcc



#!/usr/bin/env python
#  -*- coding: utf-8 -*-
# Copyright (C) 2007-2012  CEA/DEN, EDF R&D, OPEN CASCADE
#
# Copyright (C) 2003-2007  OPEN CASCADE, EADS/CCR, LIP6, CEA/DEN,
# CEDRAT, EDF R&D, LEG, PRINCIPIA R&D, BUREAU VERITAS
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# See http://www.salome-platform.org/ or email : webmaster.salome@opencascade.com
#

"""
"""
import sys,os,shutil,glob,socket
import optparse

import getAppliPath
appli_local=os.path.realpath(os.path.dirname(__file__))
APPLI=getAppliPath.relpath(appli_local,os.path.realpath(os.getenv('HOME')))

usage="""usage: %prog [options]

This procedure kill all containers that have been launched in a SALOME session on remote machines.
A SALOME session is identified by a machine name and a port number.

You need to have a well installed SALOME application with a CatalogResources.xml file.
This file is used (parsed) to collect all remote resources.
Remote resources are all the resources on remote machines not including the main local SALOME application.
"""

try:
  # cElementTree from Python 2.5+
  import xml.etree.cElementTree as etree_
except ImportError:
  try:
    import xml.etree.ElementTree as etree_
  except ImportError:
    try:
      import cElementTree as etree_
    except ImportError:
      try:
        # normal ElementTree install
        import elementtree.ElementTree as etree_
      except ImportError:
        raise

class ParseError(Exception):
  pass

catalog_file=os.path.join(appli_local,"CatalogResources.xml")

SEP=":"
if sys.platform == "win32":SEP=";"

def get_hostname():
  return socket.gethostname().split('.')[0]

class Resource:
  """Define a SALOME resource
     - components : the list of available components of the resource
  """
  def __init__(self,node):
    self.node=node
    self.components=[]
    self.resource_dir=None

  def get_rcp(self):
    protocol= self.node.get("protocol")
    if protocol and protocol[0]=='s':return "scp"
    else:return "rcp"

  def get_rsh(self):
    protocol= self.node.get("protocol")
    if protocol and protocol[0]=='s':return "ssh"
    else:return "rsh"

  def get_user(self):
    userName= self.node.get("userName")
    if not userName:
      userName=os.getenv('USER')
    return userName

  def get_host(self):
    hostname= self.node.get("hostname")
    return hostname

  def get_name(self):
    name= self.node.get("name")
    if name:return name
    return self.get_host()

  def get_appliPath(self):
    appliPath= self.node.get("appliPath")
    if appliPath is None:
      appliPath=APPLI
    return appliPath

def main():
  parser = optparse.OptionParser(usage=usage)
  parser.add_option('-p','--port', dest="port", 
                            help="The SALOME session port (default NSPORT or 2810)")


  options, args = parser.parse_args()

  if not os.path.exists(catalog_file):
    print "ERROR: the catalog file %s is mandatory" % catalog_file_base
    sys.exit(1)

  #Parse CatalogResource.xml
  doc = etree_.parse(catalog_file)

  rootNode = doc.getroot()
  if rootNode.tag != "resources":
    raise  ParseError("First level tag must be resources not %s" % rootNode.tag)

  resources=[]

  #Extract resources
  for child in rootNode:
    if child.tag != "machine":
      raise  ParseError("Second level tag must be machine not %s" % child.tag)
    resources.append(Resource(child))

  local_names=("localhost",get_hostname())

  for resource in resources:
    if resource.get_host() in local_names:continue
    command=resource.get_rsh() +" -l "+resource.get_user()+" "+resource.get_host()
    command=command+ " " + os.path.join(resource.get_appliPath(),"runRemote.sh")
    if options.port:
      port=options.port
    else:
      port=os.getenv("NSPORT") or "2810"
    command=command+ " " + get_hostname() + " " + port +" killSalomeWithPort.py " + port
    print command
    os.system(command)

if __name__ == '__main__':
  main()




# Copyright (C) 2011-2012  CEA/DEN, EDF R&D, OPEN CASCADE
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# See http://www.salome-platform.org/ or email : webmaster.salome@opencascade.com
#

"""
This module provides utility functions for the computation codes intended for
use in parametric studies. The computation codes must be implemented as a
Python script or function to use these functions. If the computation code is
implemented as a SALOME component, use module
:mod:`salome.kernel.parametric.compo_utils` instead. 
"""

def create_input_dict(deterministic_dict, parametric_input):
    """
    This function returns a dictionary containing the input values to be used
    in the computation code.
    
    :type  deterministic_dict: dict
    :param deterministic_dict: dictionary containing the fixed values (i.e.
                               non-parametric). This dictionary can be empty
                               if all variables are parametric.

    :type  parametric_input: dict
    :param parametric_input: dictionary containing the description and values
                             of the parametric variables.

    :return: a dictionary containing the input values for the computation code.
    """
    # Simply get the first point from input (no time series, single observation)
    input_point = parametric_input["inputValues"][0][0]

    if len(input_point) != len(parametric_input["inputVarList"]):
        raise Exception("Size mismatch between inputVarList and point to evaluate")

    input_dict = deterministic_dict.copy()
    for i in range(len(input_point)):
        input_dict[parametric_input["inputVarList"][i]] = input_point[i][0]

    return input_dict

def create_normal_parametric_output(output_dict, parametric_input):
    """
    This function returns a dictionary describing the output of the
    computation code in parametric studies.
    
    :type  output_dict: dict
    :param output_dict: dictionary containing the output values of the
                        computation code (the keys are the variable names, the
                        values are the variable values).

    :type  parametric_input: dict
    :param parametric_input: dictionary containing the description and values
                             of the parametric variables.

    :return: a dictionary containing the representation of the output of the
             computation code.
    """
    output_values = [[[]]]
    for output_var in parametric_input["outputVarList"]:
        output_values[0][0].append([output_dict[output_var]])
    return {"outputValues" : output_values,
            "specificOutputInfos" : [],
            "returnCode" : 0,
            "errorMessage" : ""}

def create_error_parametric_output(error_message):
    """
    This function returns a dictionary describing the output of the
    computation code in parametric studies in case of error.
    
    :type  error_message: string
    :param error_message: the error message.

    :return: a dictionary describing the error.
    """
    return {"outputValues" : [],
            "specificOutputInfos" : [],
            "returnCode" : 1,
            "errorMessage" : error_message}



#  -*- coding: iso-8859-1 -*-
# Copyright (C) 2007-2012  CEA/DEN, EDF R&D, OPEN CASCADE
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# See http://www.salome-platform.org/ or email : webmaster.salome@opencascade.com
#

"""
 When imported this module adds to CORBA objref from GenericObj type
 automatic management of reference count
 The reference count is incremented when the local proxy is created (assignment of __omni_obj attribute)
 and is decremented when the local proxy is deleted (call of __del__) 

 The GenericObj class for proxy is modified by adding two methods : __del__ and __setattr__
 The module must be imported before any other import of SALOME CORBA module
"""
import omniORB
import SALOME

def mydel(self):
    self.UnRegister()
    omniORB.CORBA.Object.__del__(self)

def mysetattr(self,attr,value):
    self.__dict__[attr]=value
    if attr == "__omni_obj":
      self.Register()

SALOME._objref_GenericObj.__del__=mydel
SALOME._objref_GenericObj.__setattr__=mysetattr




#  -*- coding: iso-8859-1 -*-
# Copyright (C) 2007-2012  CEA/DEN, EDF R&D, OPEN CASCADE
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# See http://www.salome-platform.org/ or email : webmaster.salome@opencascade.com
#

#  File   : salome_notebook.py
#  Author : Roman NIKOLAEV, Open CASCADE S.A.S.
#  Module : SALOME
#  $Header:
#
"""
Module salome_notebook gives access to Salome Notebook.
"""

import salome

class PseudoStudyForNoteBook(object):
    
    def __init__(self, **kwargs):
        self.kwargs = kwargs
        pass
    
    def GetVariableNames(self):
        return self.kwargs.keys()
    
    def IsVariable(self, variableName):
        return variableName in self.kwargs
    
    def IsReal(self, variableName):
        val = self.kwargs[variableName]
        try:
            float(val)
            return True
        except:
            pass
        return False
    
    IsInteger = IsReal
    IsBoolean = IsReal
    
    def IsString(self, variableName):
        return not self.IsReal(variableName)
    
    def GetString(self, variableName):
        return self.kwargs[variableName]
    
    def GetReal(self, variableName):
        return float(self.kwargs[variableName])
    
    GetInteger = GetReal
    GetBoolean = GetReal
    
    pass

class NoteBook:
    
    def __init__(self, Study):
        self.myStudy = Study
    
    def set(self, variableName, variable):
        """
        Create (or modify) variable with name "variableName" 
        and value equal "theValue".
        """
        if type(variable) == float:
            self.myStudy.SetReal(variableName, variable)
            
        elif type(variable) == int:
            self.myStudy.SetInteger(variableName, variable)
            
        elif type(variable) == bool:
            self.myStudy.SetBoolean(variableName, variable)
            
        elif type(variable) == str:
            self.myStudy.SetString(variableName, variable)
            
    def get(self, variableName):
        """
        Return value of the variable with name "variableName".
        """
        aResult = None
        if self.myStudy.IsVariable(variableName):
            
            if self.myStudy.IsReal(variableName):
                aResult = self.myStudy.GetReal(variableName)

            elif self.myStudy.IsInteger(variableName):
                aResult = self.myStudy.GetInteger(variableName)

            elif self.myStudy.IsBoolean(variableName):
                aResult = self.myStudy.GetBoolean(variableName)

            elif self.myStudy.IsString(variableName):
                aResult = self.myStudy.GetString(variableName)
                aResult_orig = aResult
                l = self.myStudy.GetVariableNames()
                l.remove(variableName)
                # --
                # To avoid the smallest strings to be replaced first,
                # the list is sorted by decreasing lengths
                # --
                l.sort(key=str.__len__)
                l.reverse()
                for name in l:
                    if aResult.find(name) >= 0:
                        val = self.get(name)
                        aResult = aResult.replace(name, "%s"%(val))
                        pass
                    pass
                try:
                    aResult = eval(aResult)
                except Exception, e:
                    msg = str(e)
                    msg += "\n"
                    msg += "A problem occurs while parsing "
                    msg += "the variable %s "%(variableName.__repr__())
                    msg += "with value %s ..."%(aResult_orig.__repr__())
                    msg += "\n"
                    msg += "Please, check your notebook !"
                    raise Exception(msg)
                pass
                
        return aResult
    
    def isVariable(self, variableName): 
        """
        Return true if variable with name "variableName" 
        exists in the study, otherwise return false.
        """
        return self.myStudy.IsVariable(variableName)

    def setAs(self, variableName, typ):
        value = self.get(variableName)
        value = float(typ(value))
        self.myStudy.SetStringAsDouble(variableName, value)
        return
    
    def setAsReal(self, variableName):
        self.setAs(variableName, float)
        return
    
    def setAsInteger(self, variableName):
        self.setAs(variableName, int)
        return
    
    def setAsBool(self, variableName):
        self.setAs(variableName, bool)
        return
    
    def check(self):
        for variableName in self.myStudy.GetVariableNames():
            self.get(variableName)
            pass
        return
    
    pass

def checkThisNoteBook(**kwargs):
    study = PseudoStudyForNoteBook(**kwargs)
    note_book = NoteBook(study)
    note_book.check()
    return

notebook = NoteBook(salome.myStudy)



#  -*- coding: iso-8859-1 -*-
# Copyright (C) 2007-2012  CEA/DEN, EDF R&D, OPEN CASCADE
#
# Copyright (C) 2003-2007  OPEN CASCADE, EADS/CCR, LIP6, CEA/DEN,
# CEDRAT, EDF R&D, LEG, PRINCIPIA R&D, BUREAU VERITAS
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# See http://www.salome-platform.org/ or email : webmaster.salome@opencascade.com
#

#  SALOME LifeCycleCORBA : implementation of containers and engines life cycle both in Python and C++
#  File   : LifeCycleCORBA.py
#  Author : Paul RASCLE, EDF
#  Module : SALOME
#  $Header: /home/server/cvs/KERNEL/KERNEL_SRC/src/LifeCycleCORBA_SWIG/LifeCycleCORBA.py,v 1.4.2.5.14.5.12.1 2012-04-12 14:05:16 vsr Exp $
#
import Engines
from libSALOME_LifeCycleCORBA import *

class LifeCycleCORBA (SALOME_LifeCycleCORBA):

    def __init__(self, orb = None):
        SALOME_LifeCycleCORBA.__init__(self)

    def FindOrLoadComponent(self, containerName, componentName):
        return SALOME_LifeCycleCORBA.FindOrLoad_Component(self,
                                                          containerName,
                                                          componentName)

class MachineParameters (Engines.MachineParameters):
  def __init__(self, container_name='', hostname='', componentList=[], computerList=[], OS='',
                     mem_mb=0, cpu_clock=0, nb_proc_per_node=0, nb_node=0, isMPI=False, workingdir='',
                     mode='start', policy='altcycl', parallelLib='', nb_component_nodes=0):
    Engines.MachineParameters.__init__(self,container_name, hostname, componentList, computerList, OS,
                                            mem_mb, cpu_clock, nb_proc_per_node, nb_node, isMPI, workingdir,
                                            mode, policy, parallelLib, nb_component_nodes)

class ContainerParameters (Engines.ContainerParameters):
  def __init__(self, container_name='', mode='start', workingdir='', nb_proc=0, isMPI=False, parallelLib='',resource_params=None):
    if resource_params is None:resource_params=ResourceParameters()
    Engines.ContainerParameters.__init__(self,container_name, mode, workingdir, nb_proc, isMPI, parallelLib,resource_params)

class ResourceParameters (Engines.ResourceParameters):
  def __init__(self, name="", hostname="", OS="", componentList=[],
                     nb_proc=0, mem_mb=0, cpu_clock=0, nb_node=0, nb_proc_per_node=0,
                     policy="", resList=[]):
    Engines.ResourceParameters.__init__(self, name, hostname, OS, componentList,
                                              nb_proc, mem_mb, cpu_clock, nb_node, nb_proc_per_node,
                                              policy, resList)

class JobParameters (Engines.JobParameters):
  def __init__(self, job_name="", job_type="", job_file="", env_file="", in_files=[], out_files=[],
                     work_directory="", local_directory="", result_directory="", maximum_duration="",
                     resource_required=None, queue="", specific_parameters=[]):
    Engines.JobParameters.__init__(self, job_name, job_type, job_file, env_file, in_files, out_files,
                                         work_directory, local_directory, result_directory, maximum_duration,
                                         resource_required, queue, specific_parameters)

class ResourceDefinition(Engines.ResourceDefinition):
  def __init__(self, name="", hostname="", protocol="rsh", username="", applipath="", componentList=[],
               mode="interactive", OS="", mem_mb=1, cpu_clock=1, nb_node=1, nb_proc_per_node=1,
               batch="", mpiImpl="", iprotocol="rsh"):
    Engines.ResourceDefinition.__init__(self, name, hostname, protocol, username, applipath, componentList,
                               mode, OS, mem_mb, cpu_clock, nb_node, nb_proc_per_node, batch,
                               mpiImpl, iprotocol)



#  -*- coding: iso-8859-1 -*-
# Copyright (C) 2007-2012  CEA/DEN, EDF R&D, OPEN CASCADE
#
# Copyright (C) 2003-2007  OPEN CASCADE, EADS/CCR, LIP6, CEA/DEN,
# CEDRAT, EDF R&D, LEG, PRINCIPIA R&D, BUREAU VERITAS
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# See http://www.salome-platform.org/ or email : webmaster.salome@opencascade.com
#

import sys, os,signal,string,commands

def killNamingService():
    """
    kills omniORB4 Naming Service on local machine.
    Selects process corresponding to the port used in $OMNIORB_CONFIG file.
    Works only with a single line $OMNIORB_CONFIG like
    InitRef = NameService=corbaname::<hostname>:<port>
    """
    fic=os.environ['OMNIORB_CONFIG']
    f=open(fic,'r')
    line=f.readline()
    f.close()
    port=string.split(line,':')[-1][0:4]
    command='ps -eo pid,command | grep "omniNames -start '+str(port)+'"'
    pid=string.split(commands.getoutput(command))[0]
    os.kill(int(pid),signal.SIGKILL)


def killProcess(process_id):
    """
    kills process on local machine, given a dictionary of running process
    generated by runSalome.Server() class and derived, (method run).
    kills also local Naming server.
    """
    for pid, cmd in process_id.items():
        print "stop process %s : %s"% (pid, cmd[0])
        try:
            os.kill(int(pid),signal.SIGKILL)
        except:
            print "  ---- process %s : %s inexistant"% (pid, cmd[0])
            pass
        del process_id[pid]
        pass
    killNamingService()



#  -*- coding: iso-8859-1 -*-
# Copyright (C) 2007-2012  CEA/DEN, EDF R&D, OPEN CASCADE
#
# Copyright (C) 2003-2007  OPEN CASCADE, EADS/CCR, LIP6, CEA/DEN,
# CEDRAT, EDF R&D, LEG, PRINCIPIA R&D, BUREAU VERITAS
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# See http://www.salome-platform.org/ or email : webmaster.salome@opencascade.com
#

#  File   : salome_iapp.py
#  Author : Paul RASCLE, EDF
#  Module : SALOME
#  $Header: /home/server/cvs/KERNEL/KERNEL_SRC/src/KERNEL_PY/salome_iapp.py,v 1.6.2.3.14.2.12.1 2012-04-12 14:05:13 vsr Exp $
## @package salome_iapp
# Module salome gives access to Salome GUI ressources (if GUI has been launched).
#
import salome_ComponentGUI

    #--------------------------------------------------------------------------

IN_SALOME_GUI=0

def ImportComponentGUI(ComponentName):
    if IN_SALOME_GUI:
        libName = "lib" + ComponentName + "_Swig"
        command = "from " + libName + " import *"
        exec ( command )
        constructor = ComponentName + "_Swig()"
        command = "gui = " + constructor
        exec ( command )
        return gui
    else:
        print "Warning: ImportComponentGUI(",ComponentName,") outside GUI !"
        print "calls to GUI methods may crash..."
        return salome_ComponentGUI

    #--------------------------------------------------------------------------

def SalomeGUIgetAllSelected(self):
    selNumber = self.SelectedCount()
    listSelected = []
    for i in range(selNumber):
        listSelected.append(self.getSelected(i))
    return listSelected

    #--------------------------------------------------------------------------

def hasDesktop():
    return IN_SALOME_GUI

    #--------------------------------------------------------------------------

salome_iapp_initial = 1

class SalomeOutsideGUI(object):
    """
    Provides a replacement for class SalomeGUI outside GUI process.
    Do almost nothing
    """
    global myStudyId, myStudyName
    
    def hasDesktop(self):
        """Indicate if GUI is running"""
        return False
    
    def updateObjBrowser(self, bid):
        """update the GUI object browser"""
        print "SalomeOutsideGUI: no objectBrowser update outside GUI"
        pass
    
    def getActiveStudyId(self):
        """Get the active study id"""
        print "SalomeOutsideGUI.getActiveStudyId: avoid use outside GUI"
        return myStudyId
    
    def getActiveStudyName(self):
        """Get the active study name"""
        print "SalomeOutsideGUI.getActiveStudyName: avoid use outside GUI"
        return myStudyName
    
    def SelectedCount(self):
        """Get the number of active selections"""
        print "SalomeOutsideGUI: no selection mecanism available outside GUI"
        return 0
    
    def getSelected(self, i):
        """Get the selection number i """
        print "SalomeOutsideGUI: no selection mecanism available outside GUI"
        return none
    
    def AddIObject(self, Entry):
        """Add an entry"""
        print "SalomeOutsideGUI.AddIOObject: not available outside GUI"
        pass
    
    def RemoveIObject(self, Entry):
        """Remove an entry"""
        print "SalomeOutsideGUI.REmoveIOObject: not available outside GUI"
        pass
    
    def ClearIObjects(self):
        """Clear entries"""
        print "SalomeOutsideGUI.ClearIOObject: not available outside GUI"
        pass
    
    def Display(self, Entry):
        """Display an entry"""
        print "SalomeOutsideGUI.Display: not available outside GUI"
        pass
    
    def DisplayOnly(self, Entry):
        """Display only an entry"""
        print "SalomeOutsideGUI.DisplayOnly: not available outside GUI"
        pass
    
    def Erase(self, Entry):
        """Erase en entry"""
        print "SalomeOutsideGUI.Erase: not available outside GUI"
        pass
    
    def DisplayAll(self):
        """Display all"""
        print "SalomeOutsideGUI.Erase: not available outside GUI"
        pass
    
    def EraseAll(self):
        """Erase all"""
        print "SalomeOutsideGUI.EraseAll: not available outside GUI"
        pass

    def IsInCurrentView(self, Entry):
        """Indicate if an entry is in current view"""
        print "SalomeOutsideGUI.IsIncurentView: not available outside GUI"
        return False
        
    def getComponentName(self, ComponentUserName ):
        """Get component name from component user name"""
        print "SalomeOutsideGUI.getComponentName: not available outside GUI"
        return ""
   
    def getComponentUserName( self, ComponentName ):
        """Get component user name from component name"""
        print "SalomeOutsideGUI.getComponentUserName: not available outside GUI"
        return ""
        
    #--------------------------------------------------------------------------

    
def salome_iapp_init(embedded):
    global salome_iapp_initial
    global sg,IN_SALOME_GUI

    if salome_iapp_initial:
        salome_iapp_initial=0
        if embedded:
            import libSALOME_Swig
        
            class SalomeGUI(libSALOME_Swig.SALOMEGUI_Swig):
                getAllSelected = SalomeGUIgetAllSelected

            # create a SALOMEGUI_Swig instance
            sg = SalomeGUI()
            IN_SALOME_GUI = sg.hasDesktop()
        else:
            # Not embedded in GUI
            sg=SalomeOutsideGUI()
            IN_SALOME_GUI=0
    return sg



#  -*- coding: iso-8859-1 -*-
# Copyright (C) 2007-2012  CEA/DEN, EDF R&D, OPEN CASCADE
#
# Copyright (C) 2003-2007  OPEN CASCADE, EADS/CCR, LIP6, CEA/DEN,
# CEDRAT, EDF R&D, LEG, PRINCIPIA R&D, BUREAU VERITAS
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# See http://www.salome-platform.org/ or email : webmaster.salome@opencascade.com
#

#from TestLifeCycleCORBA import *
#
import os
import Engines
import LifeCycleCORBA

import Utils_Identity
host  = Utils_Identity.getShortHostName()
#host = os.getenv( 'HOST' )

lcc = LifeCycleCORBA.LifeCycleCORBA()

try :
    obj=lcc.FindOrLoad_Component("FactoryServer","SalomeTestComponent")
    comp=obj._narrow(Engines.TestComponent)
    comp.Coucou(1)
    param={}
    #param['hostname']='cli76cc'
    param['hostname']=host
    param['container_name']='FactoryServer'
    comp=lcc.FindOrLoad_Component(param,'SalomeTestComponent')
    engine=lcc.FindComponent(param,'SalomeTestComponent')
    engine.Coucou(1)
except :
    print 'lcc.FindOrLoad_Component("FactoryServer","SalomeTestComponent") failed'

import sys
import CORBA
import CosNaming
orb = CORBA.ORB_init(sys.argv, CORBA.ORB_ID)
obj = orb.resolve_initial_references("NameService")
rootContext = obj._narrow(CosNaming.NamingContext)
context_name=[]
context_name.append(CosNaming.NameComponent( 'ContainerManager' , 'object' ) )
ContainerManager = rootContext.resolve( context_name )

try :
    myContainerparamsCPP = Engines.MachineParameters( 'myContainer' , host , 'osf' , 0 , 0 , 0 , 0 , 0 )
    computerlistCPP = [host]
    containerCPP = ContainerManager.FindOrStartContainer( myContainerparamsCPP , computerlistCPP )
    containerCPP.ping()
    ComponentparamsCPP={}
    ComponentparamsCPP['hostname']=host
    ComponentparamsCPP['container_name']='myContainer'
    compCPP=lcc.FindOrLoad_Component(ComponentparamsCPP,'SalomeTestComponent')
    compCPP.Coucou(1)
    engineCPP=lcc.FindComponent(ComponentparamsCPP,'SalomeTestComponent')
    engineCPP.Coucou(1)
except :
    print 'ContainerManager.FindOrStartContainer( myContainerparams , computerlist ) C++ failed'

try :
    myContainerparamsPy = Engines.MachineParameters( 'myContainerPy' , host , 'osf' , 0 , 0 , 0 , 0 , 0 )
    computerlistPy = [host]
    containerPy = ContainerManager.FindOrStartContainer( myContainerparamsPy , computerlistPy )
    containerPy.ping()
    ComponentparamsPy={}
    ComponentparamsPy['hostname']=host
    ComponentparamsPy['container_name']='myContainerPy'
    compPy=lcc.FindOrLoad_Component(ComponentparamsPy,'SALOME_TestComponentPy')
    compPy.Coucou(1)
    enginePy=lcc.FindComponent(ComponentparamsPy,'SALOME_TestComponentPy')
    enginePy.Coucou(1)
except :
    print 'ContainerManager.FindOrStartContainer( myContainerparams , computerlist ) Python failed'




#  -*- coding: iso-8859-1 -*-
# Copyright (C) 2007-2012  CEA/DEN, EDF R&D, OPEN CASCADE
#
# Copyright (C) 2003-2007  OPEN CASCADE, EADS/CCR, LIP6, CEA/DEN,
# CEDRAT, EDF R&D, LEG, PRINCIPIA R&D, BUREAU VERITAS
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# See http://www.salome-platform.org/ or email : webmaster.salome@opencascade.com
#

"""
This module replaces the standard import mechanism with one
that filters some imports that can't be done more than once.

This is related to the multi study feature that is implemented
by using the Python multi interpreter feature.
Some modules register objects or classes by calling modules
implemented in C. These operations can't be done multiple times.
So it's very important to control these imports.

Examples:
  - PyQt : import qt calls a C module to register classes
  - OmniORB : import *_idl calls a C module to register CORBA interfaces

Usage:
  - First import the module : import import_hook. This module will
    replace the original importer mechanism

  - Next register the module names or pattern names to filter out::
     import_hook.register_name("a")
     import_hook.register_pattern(pattern)

    where pattern is a function with one parameter, the module name
    to be imported, that returns true or false depending if this module is
    to be filtered or not.

  - Then it's done

IMPORTANT : Every subinterpretor has its own import_hook module. import_hook is not shared among subinterpretors.
The mechanism only works if shared_imported and pattern are shared between all subinterpretors.
This is done by calling init_shared_modules().
  
"""
import sys, imp, __builtin__

# Keep in shared_imported a copy of dictionnary modules
# that need to be imported only once in multi-study context
shared_imported={}

# patterns contains functions that returns 1 or 0 depending if 
# the module name (argument) must be filtered out or not
# These functions are added by calling register_pattern
patterns=[]

original_import=__builtin__.__import__

def register_name(name):
    if shared_imported.has_key(name):return
    shared_imported[name]=None

def register_pattern(pattern):
    patterns.append(pattern)

def is_shared(name):
    """ Indicate if module name is a shared module
        among multiple interpreters (return value=1)
    """
    if shared_imported.has_key(name):return 1
    for pattern in patterns:
        if pattern(name) : return 1
    return 0

def get_shared_imported(name,fromlist):
    """ If the module is registered in shared_imported
        update the sys.modules dict
        Let the real import be done by original_import
    """
    module= shared_imported.get(name)
    if module is None :
       #module name is not shared or not already imported
       #let original_import do the job
       return None

    # module is already imported and shared. Put it in sys.modules and 
    # let original_import finish the job
    sys.modules[name]=module

def get_real_module(mod,name):
    """Return effective module on import
       Standard import returns module A on import A.B
       To get module A.B use get_real_module with name "A.B"
    """
    components = name.split('.')
    for comp in components[1:]:
        mod = getattr(mod, comp)
    return mod

def set_shared_imported(name,module):
    """ Register a shared module
        Name can be a dotted name : package
    """
    shared_imported[name]=module
    #print "Module %s shared registered" % name,module

def import_module(partname, fqname, parent):
    """ Try to import module fqname
        It's parent is module parent and has name partname
    """
    #print "import_module",partname, fqname, parent
    try:
       m = sys.modules[fqname]
    except KeyError:
       pass
    else:
       return m

def ensure_fromlist(m, fromlist, recursive=0):
    """ Return the real modules list to be imported
    """
    #print "ensure_fromlist",m, fromlist, recursive
    l=[]
    for sub in fromlist:
        if sub == "*":
            if not recursive:
                try:
                    all = m.__all__
                except AttributeError:
                    pass
                else:
                    l.extend(ensure_fromlist(m, all, 1))
        else:
          #try to find if sub is an attribute (eventually dotted) of m
          components=sub.split('.')
          has_submod=True
          submod=m
          for comp in components:
            if hasattr(submod,comp):
              submod=getattr(submod, comp)
            else:
              has_submod=False
              break

          if has_submod:
            #the attribute has been found
            if type(submod) == type(sys):
               l.append(("%s.%s" % (m.__name__, sub),submod))
          else:
            subname="%s.%s" % (m.__name__, sub)
            submod = import_module(sub, subname, m)
            #if not found ignore it
            if submod:
              l.append((subname,submod))
    return l

def import_hook(name, globals=None, locals=None, fromlist=None, *args, **kwds):
    """ Import replacement for sharing modules among multiple interpreters
        Mostly update sys.modules before doing real import
    """
    #print "import_hook",name,fromlist
    m=get_shared_imported(name,fromlist)

    module= original_import(name, globals, locals, fromlist, *args, **kwds)

    if fromlist:
       #when fromlist is specified, module is the real module
       #fromlist is a list of possibly dotted name
       m=module
       for nam,mod in ensure_fromlist(m, fromlist):
           if is_shared(nam):
              set_shared_imported(nam,mod)
    else: 
       #when fromlist is not specified and name is a dotted name,
       # module is the root package not the real module
       #so we need to retrieve it
       # note: some modules like xml.dom do not play the rule
       # (import xml: no attribute dom, but import xml.dom OK)
       try:
           m=get_real_module(module,name)
       except AttributeError:
           m=None

    if type(m) == type(sys) and is_shared(m.__name__):
       set_shared_imported(m.__name__,m)

    return module

original_reload=__builtin__.reload

def reload_hook(module):
    if is_shared(module.__name__):
       return module
    return original_reload(module)

__builtin__.__import__=import_hook
# Reload is not replaced 
#__builtin__.reload=reload_hook

def init_shared_modules(shared_module):
    global shared_imported, patterns
    shared_imported=shared_module.shared_imported
    patterns=       shared_module.patterns
    for k,v in shared_imported.items():
       if v is not None:sys.modules[k]=v
    shared_imported["salome_shared_modules"]=shared_module
    import salome_shared_modules
    for m in salome_shared_modules.list_modules:
        m.init_shared_modules()



#! /usr/bin/env python
#  -*- coding: iso-8859-1 -*-
# Copyright (C) 2007-2012  CEA/DEN, EDF R&D, OPEN CASCADE
#
# Copyright (C) 2003-2007  OPEN CASCADE, EADS/CCR, LIP6, CEA/DEN,
# CEDRAT, EDF R&D, LEG, PRINCIPIA R&D, BUREAU VERITAS
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# See http://www.salome-platform.org/ or email : webmaster.salome@opencascade.com
#

#  SALOME NamingService : wrapping NamingService services
#  File   : SALOME_NamingServicePy.py
#  Author : Estelle Deville, CEA
#  Module : SALOME
#  $Header: /home/server/cvs/KERNEL/KERNEL_SRC/src/NamingService/SALOME_NamingServicePy.py,v 1.11.2.3.14.2.12.1 2012-04-12 14:05:18 vsr Exp $
## @package SALOME_NamingServicePy
# \brief Module to manage SALOME naming service from python
#
import sys
import time
from omniORB import CORBA
import CosNaming
import string
from string import *

from SALOME_utilities import *
#=============================================================================

class SALOME_NamingServicePy_i(object):
    """
      A class to manage SALOME naming service from python code
    """
    _orb = None
    _root_context=None
    _current_context=None
    _obj=None
    
    #-------------------------------------------------------------------------

    def __init__(self, orb=None):
        """
        Standard Constructor, with ORB reference.
 
        Initializes the naming service root context
        """
        #MESSAGE ( "SALOME_NamingServicePy_i::__init__" )
        if orb is None:
          orb=CORBA.ORB_init([''], CORBA.ORB_ID)
        self._orb = orb
        # initialize root context and current context
        ok = 0
        steps = 240
        while steps > 0 and ok == 0:
          try:
            obj =self._orb.resolve_initial_references("NameService")
            self._root_context =obj._narrow(CosNaming.NamingContext)
            self._current_context = self._root_context

        
            if self._root_context is None :
              #MESSAGE ( "Name Service Reference is invalid" )
              #sys.exit(1)
              MESSAGE(" Name service not found")
            else:
              ok = 1
          except (CORBA.TRANSIENT,CORBA.OBJECT_NOT_EXIST,CORBA.COMM_FAILURE):
            MESSAGE(" Name service not found")
          time.sleep(0.25)
          steps = steps - 1
        if steps == 0 and self._root_context is None: 
          MESSAGE ( "Name Service Reference is invalid" )
          sys.exit(1)

    #-------------------------------------------------------------------------

    def Register(self,ObjRef, Path):
        """ ns.Register(object,pathname )  
        
        register a CORBA object under a pathname
        """

        MESSAGE ( "SALOME_NamingServicePy_i::Register" )
        _not_exist = 0
        path_list = list(Path)
        if path_list[0]=='/':
            self._current_context = self._root_context
            #delete first '/' before split
            Path=Path[1:]

        result_resolve_path = string.split(Path,'/')
        if len(result_resolve_path)>1:
            # A directory is treated (not only an object name)
            # We had to test if the directory where ObjRef should be recorded 
            # is already done
            # If not, the new context has to be created
            _context_name = []
            for i in range(len(result_resolve_path)-1):
                _context_name.append(CosNaming.NameComponent(result_resolve_path[i],"dir"))
            
            try:
                obj = self._current_context.resolve(_context_name)
                self._current_context = obj._narrow(CosNaming.NamingContext)
            except CosNaming.NamingContext.NotFound, ex:
                _not_exist = 1
            except CosNaming.NamingContext.InvalidName, ex:
                MESSAGE ( "Register : CosNaming.NamingContext.InvalidName" )
            except CosNaming.NamingContext.CannotProceed, ex:
                MESSAGE ( "Register : CosNaming.NamingContext.CannotProceed" )
            except (CORBA.TRANSIENT,CORBA.OBJECT_NOT_EXIST,CORBA.COMM_FAILURE):
                MESSAGE ( "Register : CORBA.TRANSIENT,CORBA.OBJECT_NOT_EXIST,CORBA.COMM_FAILURE" )

            if _not_exist:
                # at least one context of the complete path is not created, we had
                # to create it or them
                _context_name = []
                for i in range(len(result_resolve_path)-1):
                    _context_name = [CosNaming.NameComponent(result_resolve_path[i],"dir")]

                    try:
                        obj = self._current_context.resolve(_context_name)
                        self._current_context = obj._narrow(CosNaming.NamingContext)
                    except CosNaming.NamingContext.NotFound, ex:
                        #This context is not created. It will be done
                        self._current_context = self._current_context.bind_new_context(_context_name)

        #The current directory is now the directory where the object should 
        #be recorded
         
        _context_name = [CosNaming.NameComponent(result_resolve_path[len(result_resolve_path)-1],"object")]
        try:
            self._current_context.bind(_context_name,ObjRef)
        except CosNaming.NamingContext.NotFound, ex:
            MESSAGE ( "Register : CosNaming.NamingContext.NotFound" )
        except CosNaming.NamingContext.InvalidName, ex:
            MESSAGE ( "Register : CosNaming.NamingContext.InvalidName" )
        except CosNaming.NamingContext.CannotProceed, ex:
            MESSAGE ( "Register : CosNaming.NamingContext.CannotProceed" )
        except CosNaming.NamingContext.AlreadyBound, ex:
            MESSAGE ( "Register : CosNaming.NamingContext.AlreadyBound, object will be rebind" )
            self._current_context.rebind(_context_name,ObjRef)
        except (CORBA.TRANSIENT,CORBA.OBJECT_NOT_EXIST,CORBA.COMM_FAILURE):
            MESSAGE ( "Register : CORBA.TRANSIENT,CORBA.OBJECT_NOT_EXIST,CORBA.COMM_FAILURE" )

    #-------------------------------------------------------------------------

    def Resolve(self, Path):
        """ ns.Resolve(pathname) -> object

        find a CORBA object (ior) by its pathname
        """
        #MESSAGE ( "SALOME_NamingServicePy_i::Resolve" )
        path_list = list(Path)
        if path_list[0]=='/':
            self._current_context = self._root_context
            #delete first '/' before split
            Path=Path[1:]

        result_resolve_path = string.split(Path,'/')
        _context_name=[]
        for i in range(len(result_resolve_path)-1):
            _context_name.append(CosNaming.NameComponent(result_resolve_path[i],"dir"))
        _context_name.append(CosNaming.NameComponent(result_resolve_path[len(result_resolve_path)-1],"object"))
        try:
            self._obj = self._current_context.resolve(_context_name)
        except CosNaming.NamingContext.NotFound, ex:
            MESSAGE ( "Resolve : CosNaming.NamingContext.NotFound" )
            self._obj = None
        except CosNaming.NamingContext.InvalidName, ex:
            MESSAGE ( "Resolve : CosNaming.NamingContext.InvalidName" )
            self._obj = None
        except CosNaming.NamingContext.CannotProceed, ex:
            MESSAGE ( "Resolve : CosNaming.NamingContext.CannotProceed" )
            self._obj = None
        except (CORBA.TRANSIENT,CORBA.OBJECT_NOT_EXIST,CORBA.COMM_FAILURE):
            MESSAGE ( "Resolve : CORBA.TRANSIENT,CORBA.OBJECT_NOT_EXIST,CORBA.COMM_FAILURE" )
            self._obj = None
        return self._obj


    #-------------------------------------------------------------------------

    def Create_Directory(self,ObjRef, Path):
        """ ns.Create_Directory(ObjRef, Path) 

        create a sub directory 
        """
        MESSAGE ( "SALOME_NamingServicePy_i::Create_Directory" )
        _not_exist = 0
        path_list = list(Path)
        if path_list[0]=='/':
            self._current_context = self._root_context
            #delete first '/' before split
            Path=Path[1:]

        result_resolve_path = string.split(Path,'/')
        _context_name = []
        for i in range(len(result_resolve_path)):
            _context_name[CosNaming.NameComponent(result_resolve_path[i],"dir")]            
            try:
                obj = self._current_context.resolve(_context_name)
                self._current_context = obj._narrow(CosNaming.NamingContext)
            except CosNaming.NamingContext.NotFound, ex:
                self._current_context = self._current_context.bind_new_context(_context_name)
            except CosNaming.NamingContext.InvalidName, ex:
                MESSAGE ( "Create_Directory : CosNaming.NamingContext.InvalidName" )
            except CosNaming.NamingContext.CannotProceed, ex:
                MESSAGE ( "Create_Directory : CosNaming.NamingContext.CannotProceed" )
            except (CORBA.TRANSIENT,CORBA.OBJECT_NOT_EXIST,CORBA.COMM_FAILURE):
                MESSAGE ( "Create_Directory : CORBA.TRANSIENT,CORBA.OBJECT_NOT_EXIST,CORBA.COMM_FAILURE" )
 
    def Destroy_Name(self,Path):
      """ ns.Destroy_Name(Path) 

        remove a name in naming service
      """
      resolve_path=string.split(Path,'/')
      if resolve_path[0] == '': del resolve_path[0]
      dir_path=resolve_path[:-1]
      context_name=[]
      for e in dir_path:
         context_name.append(CosNaming.NameComponent(e,"dir"))
      context_name.append(CosNaming.NameComponent(resolve_path[-1],"object"))
      
      try:
        self._root_context.unbind(context_name)
      except CosNaming.NamingContext.NotFound, ex:
        return
      except CORBA.Exception,ex:
        return

    def Destroy_FullDirectory(self,Path):
      """ ns.Destroy_FullDirectory(Path)

        remove recursively a directory
      """
      context_name=[]
      for e in string.split(Path,'/'):
        if e == '':continue
        context_name.append(CosNaming.NameComponent(e,"dir"))

      try:
        context=self._root_context.resolve(context_name)
      except CosNaming.NamingContext.NotFound, ex:
        return
      except CORBA.Exception,ex:
        return

      bl,bi=context.list(0)
      if bi is not None:
         ok,b=bi.next_one()
         while(ok):
            for s in b.binding_name :
               if s.kind == "object":
                  context.unbind([s])
               elif s.kind == "dir":
                  context.unbind([s])
            ok,b=bi.next_one()

      context.destroy()
      self._root_context.unbind(context_name)



#  -*- coding: iso-8859-1 -*-
# Copyright (C) 2007-2012  CEA/DEN, EDF R&D, OPEN CASCADE
#
# Copyright (C) 2003-2007  OPEN CASCADE, EADS/CCR, LIP6, CEA/DEN,
# CEDRAT, EDF R&D, LEG, PRINCIPIA R&D, BUREAU VERITAS
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# See http://www.salome-platform.org/ or email : webmaster.salome@opencascade.com
#

#  File   : salome_shared_modules.py
#  Module : SALOME
#
"""
This module with help of import_hook and *_shared_modules
filters imports when using the embedded Python interpretor.

Some imports can't be done more than once.
This is related to the multi study feature that is implemented
by using the Python multi interpreter feature.
Some modules register objects or classes by calling modules
implemented in C. These operations can't be done multiple times.
So it's very important to control these imports.

Examples:
  - PyQt : import qt calls a C module to register classes
  - OmniORB : import *_idl calls a C module to register CORBA interfaces

Usage:
  - First : the module salome_shared_modules is imported by main Python interpretor.
    It will keep a dictionnary and a list that are shared among all
    the subinterpretors and imports import_hook module that replaces
    the standard import mechanism par one that prevents more than one import
    for some modules identified by name (call register_name) or by a 
    validator (call register_pattern).

  Calls to register_name and register_pattern are done in modules named *_shared_modules
  that could be found in the path SALOMEPATH

"""
import glob,os,sys

import import_hook
# shared_imported, patterns, register_name, register_pattern
# will be shared by all Python sub interpretors
from import_hook import patterns
from import_hook import register_name
from import_hook import register_pattern

register_name("salome_shared_modules")
register_name("omniORB")
register_name("omnipatch")
register_pattern(lambda(x):x.endswith("_idl"))
register_pattern(lambda(x):x.startswith("omniORB."))

from omnipatch import shared_imported
shared_imported.update(import_hook.shared_imported)
import_hook.shared_imported=shared_imported

# Get the SALOMEPATH if set or else use KERNEL_ROOT_DIR that should be set.
salome_path=os.environ.get("SALOMEPATH",os.getenv("KERNEL_ROOT_DIR"))

list_modules=[]

# Import all *_shared_modules in the path and store them in list_modules
splitter = ":"
if sys.platform == "win32":
  splitter = ";"
path=salome_path.split(splitter)
import platform
libdir = "lib"
for rep in path:
    # Import all *_shared_modules in rep
    for f in glob.glob(os.path.join(rep,libdir,"python"+sys.version[:3],"site-packages","salome","shared_modules","*_shared_modules.py")):
        try:
           name=os.path.splitext(os.path.basename(f))[0]
           register_name(name)
           #print name + " REGISTERED"
           m=__import__(name)
           #print name + " IMPORTED"
           list_modules.append(m)
        except:
           print "Exception during register and import shared module"
           pass

# 
# If shared modules have been imported before installing import mechanism
# we add them to shared_imported
#
for name,module in sys.modules.items():
    if module and import_hook.is_shared(name) and not shared_imported.has_key(name):
       #print "Module shared added to shared_imported: ",name
       shared_imported[name]=module




#  -*- coding: iso-8859-1 -*-
# Copyright (C) 2007-2012  CEA/DEN, EDF R&D, OPEN CASCADE
#
# Copyright (C) 2003-2007  OPEN CASCADE, EADS/CCR, LIP6, CEA/DEN,
# CEDRAT, EDF R&D, LEG, PRINCIPIA R&D, BUREAU VERITAS
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# See http://www.salome-platform.org/ or email : webmaster.salome@opencascade.com
#

#  File   : batchmode_salome.py
#  Module : SALOME
#import salome_shared_modules
#
from omniORB import CORBA
from LifeCycleCORBA import *
import SALOME
import SALOMEDS
from SALOME_NamingServicePy import *

#--------------------------------------------------------------------------

def ImportComponentGUI(ComponentName):
    libName = "lib" + ComponentName + "_Swig"
    command = "from " + libName + " import *"
    exec ( command )
    constructor = ComponentName + "GUI_Swig()"
    command = "gui = " + constructor
    exec ( command )
    return gui

    #--------------------------------------------------------------------------

def SalomeGUIgetAllSelected(self):
    selNumber = self.SelectedCount()
    listSelected = []
    for i in range(selNumber):
        listSelected.append(self.getSelected(i))
    return listSelected
    #--------------------------------------------------------------------------

def generateName(prefix = None):
    import random;
    int = random.randint(1,1000);
    if prefix is None:
        return "Study" + str(int)
    else :
        return prefix + str(int)

#WITHOUTIHMfrom libSALOME_Swig import *
###from SalomePyQt import *
#WITHOUTIHMclass SalomeGUI(SALOMEGUI_Swig):
    #WITHOUTIHMgetAllSelected = SalomeGUIgetAllSelected
   
    #WITHOUTIHMdef getDesktop(self) :
#	return SalomePyQt.getDesktop()
	#WITHOUTIHMreturn None

    #WITHOUTIHMdef getSelection(self) :
#	return SalomePyQt.getSelection()
	#WITHOUTIHMreturn None

    #--------------------------------------------------------------------------

def IDToObject(id):
    myObj = None
    mySO = myStudy.FindObjectID(id);
    if mySO is not None:
        ok, anAttr = mySO.FindAttribute("AttributeIOR")
        if ok:
            AtIOR = anAttr._narrow(SALOMEDS.AttributeIOR)
            if AtIOR.Value() != "":
                myObj = orb.string_to_object(AtIOR.Value())
    return myObj

def ObjectToSObject(obj):
    mySO = None
    if obj is not None:
        ior =  orb.object_to_string(obj)
        if ior != "":
            mySO = myStudy.FindObjectIOR(ior)
    return mySO

def ObjectToID(obj):
    mySO = ObjectToSObject(obj)
    if mySO:
        return mySO.GetID()
    return ""

def IDToSObject(id):
    mySO = myStudy.FindObjectID(id);
    return mySO

    #--------------------------------------------------------------------------

def PersistentPresentation(theStudy, theSO, theWithID):
    # put the sobject's content (with subchildren) to the string
    aResult = ""
    attrs = theSO.GetAllAttributes()
    aLen = len(attrs)
    anUncopied = 0
    for a in range(0,aLen):
        attr = attrs[a]
        if isinstance(attr,SALOMEDS._objref_AttributeTreeNode):
            anUncopied += 1
        elif isinstance(attr,SALOMEDS._objref_AttributeTarget):
            anUncopied += 1
        elif isinstance(attr,SALOMEDS._objref_AttributeReal) or \
             isinstance(attr,SALOMEDS._objref_AttributeInteger) or \
             isinstance(attr,SALOMEDS._objref_AttributeName) or \
             isinstance(attr,SALOMEDS._objref_AttributeComment) or \
             isinstance(attr,SALOMEDS._objref_AttributePersistentRef) or \
             isinstance(attr,SALOMEDS._objref_AttributeLocalID) or \
             isinstance(attr,SALOMEDS._objref_AttributeUserID):
            aResult += " attribute value: " + str(attr.Value())
        elif isinstance(attr,SALOMEDS._objref_AttributeIOR):
            aResult += " attribute: IOR"
        elif isinstance(attr,SALOMEDS._objref_AttributeSequenceOfReal) or \
             isinstance(attr,SALOMEDS._objref_AttributeSequenceOfInteger):
            aResult += " Sequence: " + str(attr.CorbaSequence())
        elif isinstance(attr,SALOMEDS._objref_AttributeDrawable):
            aResult += " Drawable: " + str(attr.IsDrawable())
        elif isinstance(attr,SALOMEDS._objref_AttributeSelectable):
            aResult += " Selectable: " + str(attr.IsSelectable())
        elif isinstance(attr,SALOMEDS._objref_AttributeExpandable):
            aResult += " Expandable: " + str(attr.IsExpandable())
        elif isinstance(attr,SALOMEDS._objref_AttributeOpened):
            aResult += " Opened: " + str(attr.IsOpened())
        elif isinstance(attr,SALOMEDS._objref_AttributeTextColor):
            aResult += " TextColor: " + str(attr.TextColor())
        elif isinstance(attr,SALOMEDS._objref_AttributeTextHighlightColor):
            aResult += " TextHighlightColor: " + str(attr.TextHighlightColor())
        elif isinstance(attr,SALOMEDS._objref_AttributePixMap):
            aResult += " PixMap: " + str(attr.GetPixMap())
        elif isinstance(attr,SALOMEDS._objref_AttributeTableOfInteger) or \
             isinstance(attr,SALOMEDS._objref_AttributeTableOfReal):
            aResult += " Table with title: " + attr.GetTitle()
        elif isinstance(attr,SALOMEDS._objref_AttributePythonObject):
            aResult += " PythonObject: " + attr.GetObject()

    if theWithID:
        aResult = "sobject: " + theSO.GetID() + " nbattrs: " + str(aLen - anUncopied) + aResult + '\n'
    else:
        aResult = " nbattrs: " + str(aLen - anUncopied) + aResult + '\n'
    anIter = theStudy.NewChildIterator(theSO)
    while anIter.More():
        aResult += PersistentPresentation(theStudy, anIter.Value(), theWithID)
        anIter.Next()
    return aResult

    #--------------------------------------------------------------------------

def GetTree(theSO):
    # returns the document list tree (as list)
    aResult = [theSO.GetID()]
    anIter = myStudy.NewChildIterator(theSO)
    while anIter.More():
        aResult += GetTree(anIter.Value())
        anIter.Next()
    return aResult

    #--------------------------------------------------------------------------

def CheckCopyPaste(theSO, theInfo ,theComponentPaste):
    aRoot = theSO
    while aRoot.GetID() != "0:":
        aRoot = aRoot.GetFather()
    aTree = GetTree(aRoot)
    aStudyPersist = PersistentPresentation(myStudy, aRoot, 1)

    if not myStudyManager.CanCopy(theSO):
        raise RuntimeError, "<CanCopy> for "+theInfo+" returns false"
    
    if not myStudyManager.Copy(theSO):
        raise RuntimeError, "<Copy> for "+theInfo+" returns false"

    
    if not myStudyManager.CanPaste(theSO):
        raise RuntimeError, "<CanPaste> for "+theInfo+" returns false"

    # check: before paste study is not changed check
    if aStudyPersist != PersistentPresentation(myStudy, aRoot, 1):
        raise RuntimeError, "Study is changed before Paste calling for "+theInfo
    
    aSObj = theSO
    if theComponentPaste:
        aSObj = theSO.GetFatherComponent()
        theInfo = theInfo + "(paste for component)"
    if myStudyManager.Paste(aSObj) == None:
        raise RuntimeError, "<Paste> for "+theInfo+" returns None object"
    aNewTree = GetTree(aRoot)
    aLen = len(aTree)
    for a in range(0,aLen):
        if aTree[a] != aNewTree[a]:
            return myStudy.FindObjectID(aNewTree[a])
        
    if aLen < len(aNewTree):
        return myStudy.FindObjectID(aNewTree[aLen])
    
    raise RuntimeError, "After Copy calling the tree is not changed"
    
    #--------------------------------------------------------------------------
def FindFileInDataDir(filename):
    import os
    datadir = os.getenv("DATA_DIR")
    if datadir is not None:
        import string
        dirs = string.split(datadir, ":")
        for dir in dirs:
            file = dir + "/" + filename
            if os.path.exists(file):
                return file;
    datadir = os.getenv("KERNEL_ROOT_DIR") + "/examples/"
    file = datadir + filename
    if os.path.exists(file):
        return file;

    return None
        
#--------------------------------------------------------------------------
# initialise the ORB
orb = None

step = 0
sleeping_time = 0.01
sleeping_time_max = 1.0
while 1:
    orb = CORBA.ORB_init([''], CORBA.ORB_ID)
    if orb is not None: break
    step = step + 1
    if step > 100: break
    time.sleep(sleeping_time)
    sleeping_time = max(sleeping_time_max, 2*sleeping_time)
    pass
    
if orb is None:
    print "Warning: ORB has not been initialized !!!"

# create an LifeCycleCORBA instance
lcc = LifeCycleCORBA(orb)

step = 0
sleeping_time = 0.01
sleeping_time_max = 1.0
while 1:
    lcc = LifeCycleCORBA(orb)
    if lcc is not None: break
    step = step + 1
    if step > 100: break
    time.sleep(sleeping_time)
    sleeping_time = max(sleeping_time_max, 2*sleeping_time)
    pass
    
if lcc is None:
    print "Warning: LifeCycleCORBA object has not been initialized !!!"
    
#create a naming service instance
naming_service = SALOME_NamingServicePy_i(orb)

# get Study Manager reference
obj = None

step = 0
sleeping_time = 0.01
sleeping_time_max = 1.0
while 1:
    obj = naming_service.Resolve('myStudyManager')
    if obj is not None:break
    step = step + 1
    if step > 100: break
    time.sleep(sleeping_time)
    sleeping_time = max(sleeping_time_max, 2*sleeping_time)
    pass
     
myStudyManager = obj._narrow(SALOMEDS.StudyManager)

if myStudyManager is None:
    print "Warning: SALOMEDS.StudyManager has not been created !!!"

# create new study
aListOfOpenStudies = myStudyManager.GetOpenStudies();
myStudy = None;
if len(aListOfOpenStudies) == 0 :
    myStudy = myStudyManager.NewStudy("Study1")
else:
    myStudyName = aListOfOpenStudies[0]
    myStudy = myStudyManager.GetStudyByName(myStudyName)
    
myStudyName = myStudy._get_Name()

myStudyId = myStudy._get_StudyId()
#print myStudyId




#  -*- coding: iso-8859-1 -*-
# Copyright (C) 2007-2012  CEA/DEN, EDF R&D, OPEN CASCADE
#
# Copyright (C) 2003-2007  OPEN CASCADE, EADS/CCR, LIP6, CEA/DEN,
# CEDRAT, EDF R&D, LEG, PRINCIPIA R&D, BUREAU VERITAS
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# See http://www.salome-platform.org/ or email : webmaster.salome@opencascade.com
#

"""
  This patch of omniORB is made to make it work with multiple interpreters
  and to correct the problem of incomplete import of CORBA packages
  in some situations common in SALOME

  This patch add or modify functions in omniORB module.

  In multiple interpreters context, omniORB module is meant to be shared among
  all interpreters
"""
import sys,string,imp
import omniORB
# Map of partially-opened modules
_partialModules = {}
# Map of modules to share
shared_imported={}

# Function to return a Python module for the required IDL module name
def openModule(mname, fname=None):
    # Salome modification start
    # Be sure to use the right module dictionnary
    import sys
    # Salome modification end

    if mname == "CORBA":
        mod = sys.modules["omniORB.CORBA"]
        # Salome modification start
        shared_imported[mname]=mod
        # Salome modification end

    elif sys.modules.has_key(mname):
        mod = sys.modules[mname]

        if _partialModules.has_key(mname):
            pmod = _partialModules[mname]
            mod.__dict__.update(pmod.__dict__)
            del _partialModules[mname]
        # Salome modification start
        shared_imported[mname]=mod
        # Salome modification end

    elif _partialModules.has_key(mname):
        mod = _partialModules[mname]

    # Salome modification start
    elif shared_imported.get(mname) :
        mod = shared_imported[mname]
    # Salome modification end

    else:
        mod = newModule(mname)


    if not hasattr(mod, "__doc__") or mod.__doc__ is None:
        mod.__doc__ = "omniORB IDL module " + mname + "\n\n" + \
                      "Generated from:\n\n"

    if fname is not None:
        mod.__doc__ = mod.__doc__ + "  " + fname + "\n"

    return mod

# Function to create a new module, and any parent modules which do not
# already exist
def newModule(mname):
    # Salome modification start
    # Be sure to use the right module dictionnary
    import sys
    # Salome modification end

    mlist   = string.split(mname, ".")
    current = ""
    mod     = None

    for name in mlist:
        current = current + name

        if sys.modules.has_key(current):
            mod = sys.modules[current]

        elif _partialModules.has_key(current):
            mod = _partialModules[current]

        else:
            newmod = imp.new_module(current)
            if mod: setattr(mod, name, newmod)
            _partialModules[current] = mod = newmod

        current = current + "."

    return mod

# Function to update a module with the partial module store in the
# partial module map
def updateModule(mname):
    # Salome modification start
    # Be sure to use the right module dictionnary
    import sys
    # Salome modification end
    if _partialModules.has_key(mname):
        pmod = _partialModules[mname]
        mod  = sys.modules[mname]
        mod.__dict__.update(pmod.__dict__)
        del _partialModules[mname]

    # Salome modification start
    shared_imported[mname]=sys.modules[mname]
    # Salome modification end

omniORB.updateModule=updateModule
omniORB.newModule=newModule
omniORB.openModule=openModule




# -*- coding: iso-8859-1 -*-
# Copyright (C) 2010-2012  CEA/DEN, EDF R&D, OPEN CASCADE
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# See http://www.salome-platform.org/ or email : webmaster.salome@opencascade.com
#
__author__="gboulant"
__date__ ="$31 mars 2010 11:59:33$"

from enumerate import Enumerate

class UiException(Exception):

    TYPES = Enumerate([
        'USER',  # This type should be displayed to end user using a dialog box
        'ADMIN', # This type should be displayed to admin user in console log
        'DEVEL'  # This type should be displayed to developer only
    ])

    _UImessage = "An error occurs"
    _type = TYPES.USER

    """
    This exception should be used for functionnal error management, at least in the GUI
    part of the application, for example to set user oriented messages at point
    of exception raise.
    WARN: The exception should NOT be used to hide defaults in the algorithm, but
    only predicted error in the specified use case.
    """
    def __init__(self, message, type=TYPES.USER):
        """Canonical constructor"""
        Exception.__init__(self,message)
        self.setUIMessage(message)
        self.setType(type)

    def setUIMessage(self, UImessage):
        self._UImessage = UImessage

    def getUIMessage(self):
        return self._UImessage

    def setType(self, type):
        """Specify the type of this exception. To be choosen in the TYPES list."""
        if not self.TYPES.isValid(type):
            raise UiException("The exception type "+str(type)+" can't be used",self.TYPES.DEVEL)
        self._type = type

    def getType(self):
        return self._type

    def __str__(self):
        return self.getUIMessage()


def UserException(msg):
    return UiException(msg,UiException.TYPES.USER)

def AdminException(msg):
    return UiException(msg,UiException.TYPES.ADMIN)

def DevelException(msg):
    return UiException(msg,UiException.TYPES.DEVEL)

#
# ==============================================================================
# Basic use cases and unit test functions
# ==============================================================================
#
def somethingGoesWrong():
    raise UiException("Something goes wrong")

def TEST_uimessage():
    try:
        somethingGoesWrong()
        return False
    except UiException, err:
        print 'ERROR: %s' % str(err)
        if ( str(err) == "Something goes wrong" ):
            return True
        else:
            return False

def TEST_specificException():
    print DevelException("err")
    print AdminException("err")
    print UserException("err")
    return True

if __name__ == "__main__":
    import unittester
    unittester.run("uiexception","TEST_uimessage")
    unittester.run("uiexception","TEST_specificException")
    



#  -*- coding: iso-8859-1 -*-
# Copyright (C) 2007-2012  CEA/DEN, EDF R&D, OPEN CASCADE
#
# Copyright (C) 2003-2007  OPEN CASCADE, EADS/CCR, LIP6, CEA/DEN,
# CEDRAT, EDF R&D, LEG, PRINCIPIA R&D, BUREAU VERITAS
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# See http://www.salome-platform.org/ or email : webmaster.salome@opencascade.com
#

## @package SALOME_DriverPy
#  \brief python implementation of SALOMEDS::Driver interface
#
import SALOMEDS__POA

## Python implementation of generic SALOMEDS::Driver.
#
#
class SALOME_DriverPy_i(SALOMEDS__POA.Driver):
    """
    Should be inherited by any Python module's engine
    to provide persistence mechanism.
    """
    def __init__ (self, componentDataType):
        self._ComponentDataType = componentDataType

    def IORToLocalPersistentID(self, theSObject, IORString, isMultiFile, isASCII):
        return theSObject.GetID()

    def LocalPersistentIDToIOR(self, theSObject, PersistentID, isMultiFile, isASCII):
        return ""

    def ComponentDataType(self):
        return self._ComponentDataType

    def Save(self, theComponent, theURL, isMultiFile):
        return ""

    def SaveASCII(self, theComponent, theURL, isMultiFile):
        return self.Save(theComponent, theURL, isMultiFile)

    def Load(self, theComponent, theStream, theURL, isMultiFile):
        return 1

    def LoadASCII(self, theComponent, theStream, theURL, isMultiFile):
        return self.Load(theComponent, theStream, theURL, isMultiFile)

    def Close(self, theComponent):
        pass

    def CanPublishInStudy(self, theIOR):
        return 1

    def PublishInStudy(self, theStudy, theSObject, theObject, theName):
        return None

    def CanCopy(self, theObject):
        return 0




#  -*- coding: iso-8859-1 -*-
# Copyright (C) 2007-2012  CEA/DEN, EDF R&D, OPEN CASCADE
#
# Copyright (C) 2003-2007  OPEN CASCADE, EADS/CCR, LIP6, CEA/DEN,
# CEDRAT, EDF R&D, LEG, PRINCIPIA R&D, BUREAU VERITAS
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# See http://www.salome-platform.org/ or email : webmaster.salome@opencascade.com
#

#  SALOME Utils : general SALOME's definitions and tools
#  File   : SALOME_utilities.py
#  Module : SALOME
#
import SALOME_Trace
GLogger = SALOME_Trace.SALOME_Trace()

from launchConfigureParser import verbose

def MYTRACE ():
    if verbose():
        str = "- Trace "
        GLogger.putMessage(str + "  : ")
        

def REPERE():
    if verbose():
        GLogger.putMessage("   --------------  \n")


def BEGIN_OF(msg):
    if verbose():
        REPERE(); MYTRACE();
        GLogger.putMessage("Begin of : "+ str(msg) + "\n")
        REPERE();


def END_OF(msg):
    if verbose():
        REPERE(); MYTRACE();
        GLogger.putMessage("Normale end of : "+ str(msg) + "\n")
        REPERE();

def MESSAGE(msg):
    if verbose():
        MYTRACE()
        GLogger.putMessage(str(msg) + "\n")

def SCRUTE(var_name, var_value):
    MYTRACE();
    GLogger.putMessage(var_name + " = " + str(var_value) + "\n")

   



# This file was automatically generated by SWIG (http://www.swig.org).
# Version 1.3.40
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.
# This file is compatible with both classic and new-style classes.

from sys import version_info
if version_info >= (2,6,0):
    def swig_import_helper():
        from os.path import dirname
        import imp
        fp = None
        try:
            fp, pathname, description = imp.find_module('_libNOTIFICATION', [dirname(__file__)])
        except ImportError:
            import _libNOTIFICATION
            return _libNOTIFICATION
        if fp is not None:
            try:
                _mod = imp.load_module('_libNOTIFICATION', fp, pathname, description)
            finally:
                fp.close()
            return _mod
    _libNOTIFICATION = swig_import_helper()
    del swig_import_helper
else:
    import _libNOTIFICATION
del version_info
try:
    _swig_property = property
except NameError:
    pass # Python < 2.2 doesn't have 'property'.
def _swig_setattr_nondynamic(self,class_type,name,value,static=1):
    if (name == "thisown"): return self.this.own(value)
    if (name == "this"):
        if type(value).__name__ == 'SwigPyObject':
            self.__dict__[name] = value
            return
    method = class_type.__swig_setmethods__.get(name,None)
    if method: return method(self,value)
    if (not static) or hasattr(self,name):
        self.__dict__[name] = value
    else:
        raise AttributeError("You cannot add attributes to %s" % self)

def _swig_setattr(self,class_type,name,value):
    return _swig_setattr_nondynamic(self,class_type,name,value,0)

def _swig_getattr(self,class_type,name):
    if (name == "thisown"): return self.this.own()
    method = class_type.__swig_getmethods__.get(name,None)
    if method: return method(self)
    raise AttributeError(name)

def _swig_repr(self):
    try: strthis = "proxy of " + self.this.__repr__()
    except: strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)

try:
    _object = object
    _newclass = 1
except AttributeError:
    class _object : pass
    _newclass = 0


NOTIF_WARNING = _libNOTIFICATION.NOTIF_WARNING
NOTIF_STEP = _libNOTIFICATION.NOTIF_STEP
NOTIF_TRACE = _libNOTIFICATION.NOTIF_TRACE
NOTIF_VERBOSE = _libNOTIFICATION.NOTIF_VERBOSE
NOTIFICATION_ChannelName = _libNOTIFICATION.NOTIFICATION_ChannelName

def NOTIFICATION_date():
  """NOTIFICATION_date() -> char"""
  return _libNOTIFICATION.NOTIFICATION_date()

def NOTIFICATION_channel():
  """NOTIFICATION_channel() -> CosNA_EventChannel_ptr"""
  return _libNOTIFICATION.NOTIFICATION_channel()
class NOTIFICATION_Supplier_Swig(_object):
    """Proxy of C++ NOTIFICATION_Supplier_Swig class"""
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, NOTIFICATION_Supplier_Swig, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, NOTIFICATION_Supplier_Swig, name)
    __repr__ = _swig_repr
    def __init__(self, *args): 
        """__init__(self, char instanceName, bool notif) -> NOTIFICATION_Supplier_Swig"""
        this = _libNOTIFICATION.new_NOTIFICATION_Supplier_Swig(*args)
        try: self.this.append(this)
        except: self.this = this
    __swig_destroy__ = _libNOTIFICATION.delete_NOTIFICATION_Supplier_Swig
    __del__ = lambda self : None;
    def Send(self, *args):
        """Send(self, char graph, char node, char type, char message)"""
        return _libNOTIFICATION.NOTIFICATION_Supplier_Swig_Send(self, *args)

NOTIFICATION_Supplier_Swig_swigregister = _libNOTIFICATION.NOTIFICATION_Supplier_Swig_swigregister
NOTIFICATION_Supplier_Swig_swigregister(NOTIFICATION_Supplier_Swig)

class NOTIFICATION_Consumer_Swig(_object):
    """Proxy of C++ NOTIFICATION_Consumer_Swig class"""
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, NOTIFICATION_Consumer_Swig, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, NOTIFICATION_Consumer_Swig, name)
    __repr__ = _swig_repr
    def __init__(self): 
        """__init__(self) -> NOTIFICATION_Consumer_Swig"""
        this = _libNOTIFICATION.new_NOTIFICATION_Consumer_Swig()
        try: self.this.append(this)
        except: self.this = this
    __swig_destroy__ = _libNOTIFICATION.delete_NOTIFICATION_Consumer_Swig
    __del__ = lambda self : None;
    def Receive(self, *args):
        """
        Receive(self, char graph, char node, char type, char message, char sender, 
            long counter, char date, long stamp) -> bool
        """
        return _libNOTIFICATION.NOTIFICATION_Consumer_Swig_Receive(self, *args)

NOTIFICATION_Consumer_Swig_swigregister = _libNOTIFICATION.NOTIFICATION_Consumer_Swig_swigregister
NOTIFICATION_Consumer_Swig_swigregister(NOTIFICATION_Consumer_Swig)



